// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.clustering.matrix;

import org.datamanager.clustering.Cluster;

import org.datamanager.kernel.Entity;


/**
 * This interface marks all matrices presenting clusters of related Entities.
 * In the case of the LSA transformation, this is the DocumentTermMatrix after
 * the SVD transformation.
 *
 * @author Team Helium
 * @version $Revision: 1.3 $
 *
 */
public interface ClusterableMatrix {
    /** 
     * Returns the double representation of 'distance' between two Entities
     * within this ClusterableMatrix
     */
    public double getSimilarityBetween(Entity a, Entity b);

    /**
     * Returns a Cluster representation of the Entity documents related to
     * this document within the appropriate threshold.
     */
    public Cluster getClusterFor(Entity document);

    public double getThreshold();

    public void setThreshold(double threshold);
}

/*
 * $Log: ClusterableMatrix.java,v $
 * Revision 1.3  2002/12/20 20:52:18  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.2  2002/12/06 11:54:48  alllee
 * More codebase style
 *
 * Revision 1.1  2002/12/05 06:51:43  alllee
 * Matrix interfaces.  The Colt matrices will be modifiably used as concrete
 * implementations of these guys.
 * Adding rudimentary interfaces for clustering (borrowed a lot of ideas from
 * Alek's Orukter code).  Major refactoring expected, and some basic
 * implementations should be coming soon to start farkin with that cool
 * TouchGraph stuff.  Rule.
 *
 * Revision 1.2  2002/12/05 06:42:49  alllee
 * stupid
 *
 * Revision 1.1  2002/12/05 06:41:51  alllee
 * Initial revision
 *
 */
