// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.clustering.matrix;

import org.datamanager.clustering.matrix.ClusterableMatrix;
import org.datamanager.clustering.matrix.DocumentTermMatrixImpl;

import org.datamanager.kernel.Entity;

import org.datamanager.passiveentityvalue.WordFrequencyMapEntityValue;


/**
 * This interface marks all matrices that maintain raw document X term
 * occurrences
 *
 * @author Team Helium
 * @version $Revision: 1.10 $
 */
public interface DocumentTermMatrix {
    /**
     * Returns a ClusterableMatrix of the documents in this matrix.
     */
    public ClusterableMatrix toClusterableMatrix();

    /**
     * Adds the (word, frequency) pairs in newWords associated with the given
     * document.
     */
    public void addWords(Entity entity, WordFrequencyMapEntityValue newWords);

    /**
     * Returns the similarity between the two documents, which should be between
     * 0 and 1.  1 implies that the two documents are identical.
     */
    public double getSimilarityBetween(Entity a, Entity b);
}

/*
 * $Log: DocumentTermMatrix.java,v $
 * Revision 1.10  2002/12/20 20:52:18  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.9  2002/12/19 03:37:26  mliggett
 * Added javadoc for the interface.
 *
 * Revision 1.8  2002/12/16 10:48:46  cjdent
 *
 * Adjusted Xi's initial stab at lsa clustering to get it
 * into a more working state:
 *
 * * changed to using a sparse matrix for the document by term matrix
 * * stopped filling the matrix at the start
 * * did what appears to be the proper matrix manipulations to get
 *   a correct document by document similarity matrix
 * * Adds an addEntity() method to the ClusterStrategy method so
 *   firing off the building of the matrix or whatever else needs
 *   to be done can be the result of adding an entity to the strategy
 *
 * This is a very expensive implementation. It updates the documentXterm
 * matrix every time a document is added and then updates the
 * documentXdocument matrix. However it does not update the
 * documentXdocument matrix every time you query for info (it was
 * doing that for a while).
 *
 * The matrixNormalize() method is a heavy handed way of doing
 * someting that I'm pretty sure Colt will do for us, if I knew
 * how to ask.
 *
 * In makeDocumentByDocumentMatrix the rank() method used on
 * the SVD returns the number of non negligible values in
 * the array of singular values. This does not mean the entire
 * list is the best set of values to use for creating the reduced
 * matrix. This value can probably be shrunk by a fair
 * amount. Choosing the right value is the magic part. There's
 * probably some bogosness in this section of the code.
 *
 * Revision 1.7  2002/12/16 03:37:52  xirao
 * xirao
 *         Matrix clustering stuff. In process building the test case for it.
 *
 * Revision 1.6  2002/12/10 04:30:54  xirao
 * xi rao
 *         add DocumentTermMatrixBuilderSimpletion back with code-style run
 *
 * Revision 1.5  2002/12/09 07:53:08  cjdent
 *
 * codebase-style
 *
 * Revision 1.4  2002/12/09 01:40:27  xirao
 * xi
 * change the interface, so that fix build failture
 *
 * Revision 1.3  2002/12/08 19:08:34  xirao
 * xi rao
 * working on matrix implementation using colt package.
 *
 * Revision 1.2  2002/12/06 11:54:48  alllee
 * More codebase style
 *
 * Revision 1.1  2002/12/05 06:51:44  alllee
 * Matrix interfaces.  The Colt matrices will be modifiably used as concrete
 * implementations of these guys.
 * Adding rudimentary interfaces for clustering (borrowed a lot of ideas from
 * Alek's Orukter code).  Major refactoring expected, and some basic
 * implementations should be coming soon to start farkin with that cool
 * TouchGraph stuff.  Rule.
 *
 */
