// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.clustering.strategy;

import org.datamanager.kernel.Entity;


/**
 *
 * At the moment, this is just a marker type interface for Strategies that we
 * can use for Clustering.  It will define more methods eventually, once we
 * figure out what methods are universal across a few clustering
 * methods/strategies.
 *
 * @author Team Helium
 * @version $Revision: 1.4 $
 */
public interface ClusteringStrategy {
    public double getSimilarityBetween(Entity a, Entity b);

    public double getThreshold();

    public void setThreshold(double threshold);

    /**
     * This is for strategies that require
     * entities to be added in advance of
     * similarity check.
     * FIXME: this causes confusion in strategies
     * that don't need this.
     */
    public void addEntity(Entity entity);
}

/*
 * $Log: ClusteringStrategy.java,v $
 * Revision 1.4  2002/12/20 20:52:18  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.3  2002/12/16 10:48:46  cjdent
 *
 * Adjusted Xi's initial stab at lsa clustering to get it
 * into a more working state:
 *
 * * changed to using a sparse matrix for the document by term matrix
 * * stopped filling the matrix at the start
 * * did what appears to be the proper matrix manipulations to get
 *   a correct document by document similarity matrix
 * * Adds an addEntity() method to the ClusterStrategy method so
 *   firing off the building of the matrix or whatever else needs
 *   to be done can be the result of adding an entity to the strategy
 *
 * This is a very expensive implementation. It updates the documentXterm
 * matrix every time a document is added and then updates the
 * documentXdocument matrix. However it does not update the
 * documentXdocument matrix every time you query for info (it was
 * doing that for a while).
 *
 * The matrixNormalize() method is a heavy handed way of doing
 * someting that I'm pretty sure Colt will do for us, if I knew
 * how to ask.
 *
 * In makeDocumentByDocumentMatrix the rank() method used on
 * the SVD returns the number of non negligible values in
 * the array of singular values. This does not mean the entire
 * list is the best set of values to use for creating the reduced
 * matrix. This value can probably be shrunk by a fair
 * amount. Choosing the right value is the magic part. There's
 * probably some bogosness in this section of the code.
 *
 * Revision 1.2  2002/12/06 16:33:48  alllee
 * Argh, forgot to import Entity.  Mind is slipping... away..
 *
 * Revision 1.1  2002/12/06 16:23:14  alllee
 * Marker interface for various Strategies through which Clustering can be
 * performed.  The basic idea I'm having at this point is something along the
 * lines of:
 *
 * Matrix methods will take a ClusteringStrategy to be used upon its elements.
 *
 * Right now it looks like the Bayesian stuff that Chris posted earlier will have
 * methods like:
 *
 * double getSimilarity(ClusteringStrategy strategy, Entity a, EntitySet b)
 *
 * to find the similarity between a given Entity and a Set containing all other
 * Entities (will be slow..!)
 *
 * double getSimilarityBetween(ClusteringStrategy strategy, Entity a, Entity b)
 * as a pairwise similarity comparison between just two entities..
 *
 */
