// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.clustering.strategy.gsquared;

import java.lang.Math;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.datamanager.clustering.strategy.ClusteringStrategy;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;

import org.datamanager.passiveentityvalue.WordFrequencyMapEntityValue;

import org.datamanager.tools.Toolbox;


/**
 * This class represents a gsquared strategy for clustering Emails.
 * At this time it only does pairwise comparisons.
 *
 * FIXME: lots of unused println()s in here.
 *
 * @version $Revision: 1.6 $
 */
public class GSquaredStrategy implements ClusteringStrategy {
    public final static double DEFAULT_THRESHOLD = 0.0125;
    public final static int MINIMUM_WORD_LENGTH = 3;
    public final static int MINIMUM_WORDLIST_LENGTH = 20;
    private final static double MAP_SIZE_COMPARATOR = 0.25;
    private final static GSquaredStrategy instance = new GSquaredStrategy();

    // FIXME: this is just a prototype to test the principle
    private static final String[] STOP_WORDS = {
        "the", "when", "then", "http", "and", "from", "that", "for", "you", 
        "with", "edu", "com", "have", "about", "are", "not", "what", "date", 
        "mon", "tue", "wed", "thu", "fri", "sat", "sun", "www", "list", "there", 
        "can", "will", "some", "all", "like", "they", "was", "talk", "text", 
        "new", "net"
    };
    private static final Set stopWords = createStopWordMap(STOP_WORDS);
    private double threshold = DEFAULT_THRESHOLD;

    // FIXME: temporary for debugging
    //String documentASubject;
    //String documentBSubject;
    private GSquaredStrategy() {
    }

    /**
     * Gets the similarity between two entities by doing
     * a simple GSquared comparison of the documents.
     */
    public double getSimilarityBetween(Entity a, Entity b) {
        try {
            WordFrequencyMapEntityValue documentA = (WordFrequencyMapEntityValue) Toolbox.getFirstAttributeNamed(a, 
                                                                                                                 WordFrequencyMapEntityValue.ATTRIBUTE_NAME)
                                                                                         .getValue();
            WordFrequencyMapEntityValue documentB = (WordFrequencyMapEntityValue) Toolbox.getFirstAttributeNamed(b, 
                                                                                                                 WordFrequencyMapEntityValue.ATTRIBUTE_NAME)
                                                                                         .getValue();

            //documentASubject = Toolbox.getFirstAttributeNamed(a, "Subject").getValue().toString();
            //documentBSubject = Toolbox.getFirstAttributeNamed(b, "Subject").getValue().toString();
            return getGSquaredProbabilityForPair(documentA, documentB);
        } catch (DataManagerException exception) {
            // FIXME: Bad monkey exception
            exception.printStackTrace();
            throw new RuntimeException(exception);
        }
    }

    /**
     * Calculates the GSquared value for the provide word maps.
     */
    private double getGSquaredProbabilityForPair(final WordFrequencyMapEntityValue documentA, 
                                                 final WordFrequencyMapEntityValue documentB) {
        double probability = -1;

        // if we have enough words to go on, do the math
        if (checkForValidSizeDocuments(documentA, documentB)) {
            Set mergedWordSet = createMergedWordSet(documentA, documentB);

            //System.err.println("WordList: " + mergedWordList.size());
            if (mergedWordSet.size() >= MINIMUM_WORDLIST_LENGTH) {
                probability = getGSquaredWithWordSet(mergedWordSet, documentA, 
                                                     documentB);
            }
        }

        return probability;
    }

    /**
     * Calculates the gSquared of two document maps given the provided word
     * list.
     *
     */
    private double getGSquaredWithWordSet(final Set words, 
                                          final WordFrequencyMapEntityValue documentA, 
                                          final WordFrequencyMapEntityValue documentB) {
        double probability = 0;

        Map wordSumMap = new HashMap();

        double sumWordFrequenciesA = getSumWordFrequencies(words, documentA, 
                                                           wordSumMap);
        double sumWordFrequenciesB = getSumWordFrequencies(words, documentB, 
                                                           wordSumMap);

        double observedFrequenciesSum = sumWordFrequenciesA + 
                                        sumWordFrequenciesB;

        double sumVarianceA = 0;
        double sumVarianceB = 0;

        Iterator wordsIterator = words.iterator();

        while (wordsIterator.hasNext()) {
            String word = (String) wordsIterator.next();
            double frequencySumForWord = ((Number) wordSumMap.get(word)).doubleValue();
            double frequencyForWordA = documentA.getFrequencyOf(word);
            double frequencyForWordB = documentB.getFrequencyOf(word);
            double expectedWordA = ((sumWordFrequenciesA / observedFrequenciesSum) * frequencySumForWord);
            double expectedWordB = ((sumWordFrequenciesB / observedFrequenciesSum) * frequencySumForWord);


            //System.err.println("Word: " + word);
            //System.err.println("AWord info, freq: " + frequencyForWordA + " exp: " + expectedWordA);
            //System.err.println("BWord info, freq: " + frequencyForWordB + " exp: " + expectedWordB);
            // chi-squared
            sumVarianceA += ((Math.pow((frequencyForWordA - expectedWordA), 2)) / expectedWordA);
            sumVarianceB += ((Math.pow((frequencyForWordB - expectedWordB), 2)) / expectedWordB);

            // g-squared
            //sumVarianceA += (frequencyForWordA * Math.log(frequencyForWordA / expectedWordA));
            //sumVarianceB += (frequencyForWordB * Math.log(frequencyForWordB / expectedWordB));
            //fiddling
            //sumVarianceA += (frequencyForWordA * (frequencyForWordA / expectedWordA));
            //sumVarianceB += (frequencyForWordB * (frequencyForWordB / expectedWordB));
        }

        //double squareValue = 2 * (sumVarianceA + sumVarianceB);
        double squareValue = sumVarianceA + sumVarianceB;

        probability = squareValueToProbability(squareValue, words.size() - 1);

        //System.err.println("SubjectA: " + documentASubject);
        //System.err.println("SubjectB: " + documentBSubject);
        //System.err.println("squarevalue : " + squareValue);
        //System.err.println("probability : " + probability);
        //System.err.println("words size : " + words.size());
        return probability;
    }

    /**
     * Does some magic to translate the g/chi square value to a probability rather
     * than some other value. 
     *
     * FIXME: this isn't accurate.
     * We don't do anything with DoF either.
     */
    private double squareValueToProbability(double squareValue, 
                                            double degreesOfFreedom) {
        squareValue++;

        //return 1 - Math.abs(squareValue);
        //return (squareValue/degreesOfFreedom);
        //return 1/squareValue;
        //return 1/(squareValue/degreesOfFreedom);
        //return Math.pow((1/(squareValue/degreesOfFreedom)), 10); //has promise
        //return 1-(1/(squareValue)); //has promise
        //return (1 - (1/Math.log(squareValue)));
        //return (1 - 1/(1/Math.log(squareValue)));
        //return squareValue/2000
        return 1 / squareValue;

        //return 1 - (Math.log(1/squareValue)/Math.log(10));
    }

    /**
     * Reports the sum of the frequency of the provide words in the provided document map.
     * Updates a map of total word values as a result.
     */
    private double getSumWordFrequencies(final Set words, 
                                         final WordFrequencyMapEntityValue document, 
                                         Map wordSumMap) {
        Iterator wordsIterator = words.iterator();

        double sum = 0;

        while (wordsIterator.hasNext()) {
            String word = (String) wordsIterator.next();
            double frequencyOfWord = document.getFrequencyOf(word);
            sum += frequencyOfWord;

            if (wordSumMap.containsKey(word)) {
                wordSumMap.put(word, 
                               new Double(((Number) wordSumMap.get(word)).doubleValue() + frequencyOfWord));
            } else {
                wordSumMap.put(word, new Double(frequencyOfWord));
            }
        }

        return sum;
    }

    /**
     * Returns true if these two documents are within a half size of one another.
     */
    private boolean checkForValidSizeDocuments(final WordFrequencyMapEntityValue documentA, 
                                               final WordFrequencyMapEntityValue documentB) {
        //double totalWordsA = documentA.getTotalNumberOfWords();
        //double totalWordsB = documentB.getTotalNumberOfWords();
        double totalWordsA = documentA.getNumberOfUniqueWords();
        double totalWordsB = documentB.getNumberOfUniqueWords();

        double proportion = (Math.min(totalWordsA, totalWordsB)) / Math.max(totalWordsA, 
                                                                            totalWordsB);

        return (proportion > MAP_SIZE_COMPARATOR);
    }

    private Set createMergedWordSet(final WordFrequencyMapEntityValue documentA, 
                                    final WordFrequencyMapEntityValue documentB) {
        return createUnionWordSet(documentA, documentB);

        //return createIntersectionWordSet(documentA, documentB);
    }

    private Set createUnionWordSet(final WordFrequencyMapEntityValue documentA, 
                                   final WordFrequencyMapEntityValue documentB) {
        Set mergedWordSet = new HashSet();

        mergedWordSet.addAll(documentA.getWordSet());
        mergedWordSet.addAll(documentB.getWordSet());

        Iterator wordIterator = mergedWordSet.iterator();

        while (wordIterator.hasNext()) {
            String word = (String) wordIterator.next();

            if (!wordIsAcceptable(word)) {
                wordIterator.remove();
            }
        }

        return mergedWordSet;
    }

    private Set createIntersectionWordSet(final WordFrequencyMapEntityValue documentA, 
                                          final WordFrequencyMapEntityValue documentB) {
        double numberWordsA = documentA.getNumberOfUniqueWords();
        double numberWordsB = documentB.getNumberOfUniqueWords();

        if (numberWordsA > numberWordsB) {
            return getIntersectionWordsFromMaps(documentA, documentB);
        } else {
            return getIntersectionWordsFromMaps(documentB, documentA);
        }
    }

    /**
     * Creates a list of words found in both documentA and 
     * documentB assuming documentA has more unique words.
     */
    private Set getIntersectionWordsFromMaps(final WordFrequencyMapEntityValue documentA, 
                                             final WordFrequencyMapEntityValue documentB) {
        Set wordSet = new HashSet();

        Iterator iteratorA = documentA.getWordSet().iterator();

        while (iteratorA.hasNext()) {
            String wordA = (String) iteratorA.next();

            if (wordIsAcceptable(wordA)) {
                double frequencyA = documentA.getFrequencyOf(wordA);
                double frequencyB = documentB.getFrequencyOf(wordA);

                if (frequencyB >= 1) {
                    wordSet.add(wordA);
                }
            }
        }

        return wordSet;
    }

    /**
     * Tests a string to see if it matches a set of rules for
     * appropriateness for this clustering strategy.
     *
     * FIXME: this should be a filtering strategy.
     */
    private boolean wordIsAcceptable(String word) {
        return ((word.length() >= MINIMUM_WORD_LENGTH) && 
               !wordIsStopWord(word));
    }

    /**
     * Compares the given word with a stop word list.
     *
     * FIXME: this should use a global stop word list or
     * similar mechanism.
     */
    private boolean wordIsStopWord(String word) {
        return stopWords.contains(word);
    }

    /**
     * Creates a Set which is the list of stop words
     * that are ignored in comparisons.
     */
    private static Set createStopWordMap(String[] words) {
        Set stopWords = new HashSet();

        for (int i = 0; i < words.length; i++) {
            stopWords.add(words[i]);
        }

        return stopWords;
    }

    public final static GSquaredStrategy getInstance() {
        return instance;
    }

    /**
     * Satisfying interface.
     */
    public void addEntity(Entity entity) {
    }

    public void setThreshold(double threshold) {
        this.threshold = threshold;
    }

    public double getThreshold() {
        return this.threshold;
    }
}

/*
 * $Log: GSquaredStrategy.java,v $
 * Revision 1.6  2002/12/20 20:52:19  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.5  2002/12/16 10:48:47  cjdent
 *
 * Adjusted Xi's initial stab at lsa clustering to get it
 * into a more working state:
 *
 * * changed to using a sparse matrix for the document by term matrix
 * * stopped filling the matrix at the start
 * * did what appears to be the proper matrix manipulations to get
 *   a correct document by document similarity matrix
 * * Adds an addEntity() method to the ClusterStrategy method so
 *   firing off the building of the matrix or whatever else needs
 *   to be done can be the result of adding an entity to the strategy
 *
 * This is a very expensive implementation. It updates the documentXterm
 * matrix every time a document is added and then updates the
 * documentXdocument matrix. However it does not update the
 * documentXdocument matrix every time you query for info (it was
 * doing that for a while).
 *
 * The matrixNormalize() method is a heavy handed way of doing
 * someting that I'm pretty sure Colt will do for us, if I knew
 * how to ask.
 *
 * In makeDocumentByDocumentMatrix the rank() method used on
 * the SVD returns the number of non negligible values in
 * the array of singular values. This does not mean the entire
 * list is the best set of values to use for creating the reduced
 * matrix. This value can probably be shrunk by a fair
 * amount. Choosing the right value is the magic part. There's
 * probably some bogosness in this section of the code.
 *
 * Revision 1.4  2002/12/12 03:13:44  cjdent
 *
 * This is an update of the GSquaredStrategy to use unions of words
 * rather than intersection. This required some changes to the math
 * to get reasonable results. Now back to chi-squared at the moment
 * as that produces better results.
 *
 * The clusters generated by this look better seem more meaningful.
 *
 * Revision 1.3  2002/12/09 07:11:59  cjdent
 *
 * A great deal of tweaking to get to a point where the created
 * linkings are somewhat meaningful in certain domains. Is
 * susceptible to problems like sig files and the like. Has
 * lots of tweakable areas.
 *
 * But for now it does some things that make it a bit better. Some
 * of these things should be moved out to interfaces, especially
 * the stop with checking word lengths and stop words.
 *
 * Changes:
 *
 * 1) there is now a stopWords Set used when creating the list of
 *    words in both documents
 * 2) when getting a number of words in the current doc, only
 *    non-stop words are counted
 * 3) there has to be MINIMUM_WORDLIST_LENGTH words available
 *    for the math or it won't bother calculating
 * 4) the proportion of words in both documents compared with
 *    the number of words in the primary doc is cheched against
 *    a threshold before calculating
 * 5) it's actually g-squared now instead of chi
 *
 * This is a very tweakable class, not in that it has a lot of
 * handles for tweaking, but in that it needs to be tweaked.
 *
 * It's only meaningful some of the time.
 *
 * There's a lot here that can probably used in the NaiveBayes
 * set up. In fact we can probably move some stuff to the
 * WordFrequencyMapEntity value or some more general place.
 *
 * Revision 1.2  2002/12/09 02:46:03  cjdent
 *
 * codebase-style
 *
 * Revision 1.1  2002/12/09 02:44:01  cjdent
 *
 * Moving my fiddling with gsquared from within
 * TouchgraphEntityDisplayPanel to a proper strategy. In the process
 * fleshed out the math to something that should be more correct, and
 * added in some methods to avoid documents not being friendly with
 * one another lengthwise.
 *
 * The results now are actually chi-square not g-square. I'm committing
 * now to get that into CVS but am going to clobber it here in a
 * sec with proper g-square (which works better with low frequencies, which
 * we have).
 *
 * No use of stop words.
 *
 * This isn't being called from anything that is currently committed.
 *
 *
 */
