// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.clustering.strategy.lsa;

import cern.colt.matrix.linalg.SingularValueDecomposition;

import org.datamanager.clustering.matrix.DocumentTermMatrix;
import org.datamanager.clustering.matrix.DocumentTermMatrixImpl;
import org.datamanager.clustering.strategy.ClusteringStrategy;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;

import org.datamanager.passiveentityvalue.WordFrequencyMapEntityValue;

import org.datamanager.tools.Debug;
import org.datamanager.tools.Toolbox;


/**
 * This class represents a LSA strategy for clustering emails.
 * Latent Semantic Analysis (or LSA) gives the statistical co-occurrence picks up of the semantic
 * information.
 *
 * @author Team Helium
 * @version $Revision: 1.6 $
 */
public class LsaStrategy implements ClusteringStrategy {
    public final static double DEFAULT_THRESHOLD = 0.70;
    public final static LsaStrategy instance = new LsaStrategy();
    private double threshold = DEFAULT_THRESHOLD;
    private DocumentTermMatrix docTermMatrix;

    private LsaStrategy() {
        docTermMatrix = DocumentTermMatrixImpl.getDocumentTermMatrix();
    }

    /**
     * Gets the similarity between two entities by doing
     * a LSA look up for documents documents clustering matrix.
     */
    public double getSimilarityBetween(Entity a, Entity b) {
        return docTermMatrix.getSimilarityBetween(a, b);
    }

    /**
     * Adds the entity and words within to the Document
     * by Term matrix.
     *
     * FIXME: this place is probably no better than
     * any of other the other places for this.
     */
    public void addEntity(Entity entity) {
        WordFrequencyMapEntityValue mapEntityValue;

        try {
            mapEntityValue = (WordFrequencyMapEntityValue) Toolbox.getFirstAttributeNamed(
                                                                   entity, 
                                                                   WordFrequencyMapEntityValue.ATTRIBUTE_NAME)
                                                                  .getValue();
            docTermMatrix.addWords(entity, mapEntityValue);
        } catch (DataManagerException exception) {
            Debug.writeLogMessage("error in kernel");
        } catch (NullPointerException exception) {
            // this entity don't have WordFrequencyMapEntityValue, so we simply
            // ignore this event
        }
    }

    public double getThreshold() {
        return threshold;
    }

    public void setThreshold(double threshold) {
        this.threshold = threshold;
    }

    public final static LsaStrategy getInstance() {
        return instance;
    }
}