// For licensing, see: http://helium.knownspace.org/license.html
// AttributeNameContainsConstraint.java
// @author Gordon Murphy
// Modified:
//    Ran it through JIndent.
//     -- Matt 26 Dec 1999
//    Used to be InterfaceNameContainsConstraint, renamed.
//     -- Matt 29 Dec 1999
// 
// Created: 199910071638
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;

import org.datamanager.passiveentityvalue.StringEntityValue;


/**
 * Selects for Entities which have attributes of a specified name which contain
 * a specified string.
 *
 * @author Gordon Murphy
 */
public class AttributeNameContainsConstraint extends AbstractEntityConstraint {
    /** The attribute name we're trying to match against. */
    private String attributeName;

    /** The value we want to be a substring of the attribute. */
    private String matchValue;

    /**
     * Creates a new AttributeNameContainstConstraint which matches Entities
     * which have StringEntityValue attributes whose name is
     * <code>attributeName</code> and whose value contains
     * <code>matchValue</code>.
     */
    public AttributeNameContainsConstraint(String attributeName, 
                                           String matchValue) {
        this.attributeName = attributeName;
        this.matchValue = matchValue;
    }

    protected boolean describes(Entity entity) throws DataManagerException {
        boolean temp = false;

        String entityName = entity.getName();
        Entity[] attributes = entity.getAttributes(
                                      new NameEqualsConstraint(attributeName));

        for (int i = 0; i < attributes.length; i++) {
            StringEntityValue value = (StringEntityValue) (attributes[i].getValue());

            if (value.indexOf(matchValue) >= 0) {
                temp = true;

                break;
            }
        }

        return temp;
    }
}

/*
 * $Log: AttributeNameContainsConstraint.java,v $
 * Revision 1.4  2002/12/20 20:52:19  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.3  2002/10/29 04:00:44  mliggett
 * Modified AttributeNameContainsConstraint to do what its name implies.
 * Wrote a test for it.
 *
 */
