// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;

import org.datamanager.passiveentityvalue.StringEntityValue;


/**
 * Selects for Entities which have attributes of a specified name which equal
 * a specified string.
 *
 * @author Matt Liggett
 */
public class AttributeNameEqualsConstraint extends AbstractEntityConstraint {
    /** The attribute name we're trying to match against. */
    private String attributeName;

    /** The value we want to be a substring of the attribute. */
    private String matchValue;

    /**
     * Creates a new AttributeNameEqualstConstraint which matches Entities
     * which have StringEntityValue attributes whose name is
     * <code>attributeName</code> and whose value equals
     * <code>matchValue</code>.
     */
    public AttributeNameEqualsConstraint(String attributeName, 
                                         String matchValue) {
        this.attributeName = attributeName;
        this.matchValue = matchValue;
    }

    protected boolean describes(Entity entity) throws DataManagerException {
        String entityName = entity.getName();
        Entity[] attributes = entity.getAttributes(
                                      new NameEqualsConstraint(attributeName));

        for (int i = 0; i < attributes.length; i++) {
            StringEntityValue value = (StringEntityValue) (attributes[i].getValue());

            if (value.equals(matchValue)) {
                return true;
            }
        }

        return false;
    }
}

/*
 * $Log: AttributeNameEqualsConstraint.java,v $
 * Revision 1.3  2002/12/20 20:52:19  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.2  2002/11/04 01:40:14  mliggett
 * Fixed cut/paste typos in javadoc.
 *
 * Revision 1.1  2002/11/04 01:36:09  mliggett
 * New constraint and its unit tests.
 *
 */
