// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;

import org.datamanager.passiveentityvalue.StringEntityValue;


/**
 * Selects for Entities which have attributes of a specified name which match a
 * specified string.
 *
 * @author Matt Liggett
 */
public class AttributeStringMatchConstraint extends AbstractEntityConstraint {
    /** The attribute name we're trying to match against. */
    private String attributeName;

    /** The string value we're trying to match. */
    private String matchValue;

    /**
     * Creates a new AttributeStringMatchConstraint which matches Entities
     * which have StringEntityValue attributes whose name is
     * <code>attributeName</code> and whose value matches
     * <code>matchValue</code> exactly.
     */
    public AttributeStringMatchConstraint(String attributeName, 
                                          String matchValue) {
        this.attributeName = attributeName;
        this.matchValue = matchValue;
    }

    protected boolean describes(Entity entity) throws DataManagerException {
        String entityName = entity.getName();
        Entity[] attributes = entity.getAttributes(
                                      new NameEqualsConstraint(attributeName));

        for (int i = 0; i < attributes.length; i++) {
            if (attributes[i].getValue() instanceof StringEntityValue) {
                StringEntityValue value = (StringEntityValue) (attributes[i].getValue());

                if (value.equals(matchValue)) {
                    return true;
                }
            }
        }

        return false;
    }
}

/*
 * $Log: AttributeStringMatchConstraint.java,v $
 * Revision 1.4  2002/12/20 20:52:19  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.3  2002/10/30 07:40:06  cjdent
 *
 * Fixed a typo in a comment. Was in there trying to learn about constraints.
 *
 * Revision 1.2  2002/10/29 13:57:44  mafarrel
 * Codebase-style ran.
 *
 * EmailHandlerSimpleton is now the EmailRetrieverSimpleton and it uses
 * JavaMail to its full extent. The code still need a bit of work and
 * testing, but it's there.
 *
 * Revision 1.1  2002/10/29 04:15:18  mliggett
 * Wrote AttributeStringMatchConstraint, which works just like
 * AttributeNameContainsConstraint but is stricter (exact match instead of
 * substring).
 * Wrote unit tests for it.
 *
 */
