// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.constraint;

import java.util.Date;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EntityValue;

import org.datamanager.passiveentityvalue.DateEntityValue;


/**
 * Matches a DateEntityValue with a range described by two Date.
 * This class matches any Entity that has a
 * DateEntityValue that is between the Dates given in
 * the constructor of this class.
 * 
 */
public class DateValueRangeConstraint extends AbstractEntityConstraint {
    /**
     * The minimum and maximum Date values to match.
     */
    private Date minValue;
    private Date maxValue;

    /**
     * The default constructor. It uses indexOf() to
     * find the given String in a StringEntityValue.
     */
    public DateValueRangeConstraint(Date min, Date max) {
        this.minValue = min;
        this.maxValue = max;
    }

    /**
     * Decide if the Entity is valid or not. It uses
     * indexOf() to find the given String in a
     * StringEntityValue.
     */
    protected boolean describes(Entity defendant) throws DataManagerException {
        boolean temp = false;

        EntityValue entityValue = defendant.getValue();

        if (entityValue instanceof DateEntityValue) {
            Date dateValue = ((DateEntityValue) entityValue).getDate();

            temp = (dateValue.after(minValue) && dateValue.before(maxValue));
        }

        return temp;
    }
}