// For licensing, see: http://helium.knownspace.org/license.html

/**
 * NameContainsConstraint.java
 *
 * Author: Benjamin Keil
 * Modified:
 *    Made it extend AbstractEntityConstraint.
 *     -- Matt
 *    Made code readable, added javadoc.
 *     -- Matt 26 Dec 1999
 *
 * Created: 199910071638
 */
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;


/**
 * Check to see if the name of an Entity contains a
 * given String.
 *
 * @author Benjamin Keil
 */
public class NameContainsConstraint extends AbstractEntityConstraint {
    /**
     * Part of a valid name.
     */
    private String partialName;

    /**
     * Create a new NameContainsConstraint that matches
     * the given String.
     *
     * @param partialName A String to find in the name of
     *                    an Entity.
     */
    public NameContainsConstraint(String partialName) {
        this.partialName = partialName;
    }

    /**
     * Check to see if the name of the given Entity
     * contains the String given to the constructor
     * of this constraint.
     *
     * @param defendant An Entity to check.
     *
     * @return Whether the name of the Entity contains
     *         the string given in the constructor.
     */
    protected boolean describes(Entity defendant) throws DataManagerException {
        String entityName = defendant.getName();

        return (entityName.indexOf(partialName) != -1);
    }
}