// For licensing, see: http://helium.knownspace.org/license.html

/**
 * NameEqualsConstraint.java
 *
 * Author: Benjamin Keil
 * Modified:
 *    Made it an AbstractEntityConstraint.
 *     -- Matt
 *    Cleaned the code, added javadoc.
 *     -- Matt 26 Dec 1999
 *
 * Created: 199910071638
 */
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;

import org.datamanager.tools.Debug;


/**
 * Check the name of an Entity.
 *
 * @author Benjamin Keil
 */
public class NameEqualsConstraint extends AbstractEntityConstraint {
    /**
     * The String to match in a name.
     */
    private String name;

    /**
     * Create a new NameEqualsConstraint.
     *
     * @param name The name to target.
     */
    public NameEqualsConstraint(String name) {
        this.name = name;
    }

    /**
     * Check to see if the String given in the constructor
     * of this constraint is in the name of the given
     * Entity.
     *
     * @param defendant An Entity to check.
     *
     * @return Whether the target String was in the
     *         name of the given Entity.
     */
    protected boolean describes(Entity defendant) throws DataManagerException {
        return defendant.getName().equals(name);
    }
}