// For licensing, see: http://helium.knownspace.org/license.html

/**
 * NameEqualsIgnoringCaseConstraint.java
 */
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;


/**
 * Check the name of an Entity and ignore case.
 *
 * @author Matthew Farrellee
 */
public class NameEqualsIgnoringCaseConstraint
    extends AbstractEntityConstraint {
    /**
     * The String to match in a name.
     */
    private String name;

    /**
     * Create a new NameEqualsIgnoringCaseConstraint.
     *
     * @param name The name to target.
     */
    public NameEqualsIgnoringCaseConstraint(String name) {
        this.name = name;
    }

    /**
     * Check to see if the String given in the constructor
     * of this constraint is in the name of the given
     * Entity, ignoring the case of both Strings.
     *
     * @param defendant An Entity to check.
     *
     * @return Whether the target String was in the
     *         name of the given Entity.
     */
    protected boolean describes(Entity defendant) throws DataManagerException {
        return defendant.getName().equalsIgnoreCase(name);
    }
}