// For licensing, see: http://helium.knownspace.org/license.html

/**
 * NotEntityConstraint.java
 */
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;


/**
 * Logical Not for EntityConstraints.
 *
 * @author Matthew Farrellee
 */
public class NotEntityConstraint extends AbstractEntityConstraint {
    /**
     * The EntityConstraints to negate.
     */
    private EntityConstraint negatedEntity;

    /**
     * Create a NotEntityConstraint to work on Entities.
     *
     * @param negated EntityConstraint to negate.
     */
    public NotEntityConstraint(EntityConstraint negated) {
        this.negatedEntity = negated;
    }

    /**
     * Check to see if an Entity satisfies the EntityConstraint
     * given in the constructor and then negate the result.
     *
     * @param defendant An Entity to check.
     *
     * @return Whether the Entity is valid or not.
     */
    protected boolean describes(Entity defendant) throws DataManagerException {
        return !negatedEntity.accepts(defendant);
    }
}