// For licensing, see: http://helium.knownspace.org/license.html

/**
 * StringValueContainsConstraint.java
 */
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EntityValue;

import org.datamanager.passiveentityvalue.StringEntityValue;


/**
 * Matches a StringEntityValue with any given String.
 * This class matches any Entity that has a
 * StringEntityValue that contains the String given in
 * the constructor of this class. Currently this
 * constraint only does an indexOf() to see if the
 * value contains the given String.
 * 
 * @author Matthew Farrellee
 */
public class StringValueContainsConstraint extends AbstractEntityConstraint {
    /**
     * The value to find.
     */
    private String value;

    /**
     * The default constructor. It uses indexOf() to
     * find the given String in a StringEntityValue.
     */
    public StringValueContainsConstraint(String value) {
        this.value = value;
    }

    /**
     * Decide if the Entity is valid or not. It uses
     * indexOf() to find the given String in a
     * StringEntityValue.
     */
    protected boolean describes(Entity defendant) throws DataManagerException {
        boolean temp = false;

        EntityValue entityValue = defendant.getValue();

        if (entityValue instanceof StringEntityValue) {
            String stringValue = entityValue.toString();

            temp = (stringValue.indexOf(value) != -1);
        }

        return temp;
    }
}