// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.constraint;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EntityValue;

import org.datamanager.passiveentityvalue.StringEntityValue;


/**
 * Matches a StringEntityValue with a given regular expression.
 *
 * @see java.util.regex.Pattern
 * @version $Revision: 1.2 $
 */
public class StringValueMatchesConstraint extends AbstractEntityConstraint {
    /**
     * The pattern to match.
     */
    private Pattern pattern;

    /**
     * Creates a new StringValueMatchesConstraint with the given pattern.
     */
    public StringValueMatchesConstraint(Pattern pattern) {
        this.pattern = pattern;
    }

    /**
     * Creates a new StringValueMatchesConstraint with the given pattern.
     */
    public StringValueMatchesConstraint(String patternString) {
        this.pattern = Pattern.compile(patternString);
    }

    protected boolean describes(Entity defendant) throws DataManagerException {
        EntityValue value = defendant.getValue();

        return ((value instanceof StringEntityValue) && 
               (pattern.matcher(value.toString()).find()));
    }
}

/*
 * 
 * $Log: StringValueMatchesConstraint.java,v $
 * Revision 1.2  2002/12/20 20:52:19  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.1  2002/11/16 19:51:49  mliggett
 * Adding new constraint which does pattern matching using java.util.regex.*,
 * and also a couple basic unit tests.
 *
 * This is in preparation for smarter Subject: searching.
 *
 *
 */
