// For licensing, see: http://helium.knownspace.org/license.html

/**
 * ValueInRangeConstraint.java
 *
 * Author: Benjamin Keil
 * Modified:
 *    Made it extend AbstractEntityConstraint.
 *      -- Matt
 *    Made the code readable, ran it through JIndent,
 *    and added javadoc.
 *      -- Matt 26 Dec 1999
 * 
 * Created 199910111458
 */
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EntityValue;

import org.datamanager.passiveentityvalue.NumericEntityValue;


/**
 * See if the value of an Entity is within a specific range.
 *
 * @author Benjamin Keil
 */
public class ValueInRangeConstraint extends AbstractEntityConstraint {
    /**
     * The lower bounds.
     */
    private double low;

    /**
     * The upper bounds.
     */
    private double high;

    /**
     * Create a new ValueInRangeConstraint.
     *
     * @param low Lower bounds.
     * @param high Upper bounds.
     */
    public ValueInRangeConstraint(double low, double high) {
        this.low = low;
        this.high = high;
    }

    /**
     * Decide if the Entity is acceptable or not.
     *
     * @param defendant Entity to check.
     *
     * @return Whether the Entity satisfies this constraint
     *         or not.
     */
    protected boolean describes(Entity defendant) throws DataManagerException {
        if (defendant == null) {
            return false;
        }

        EntityValue val = defendant.getValue();

        if ((val instanceof NumericEntityValue) && (val != null)) {
            return ((NumericEntityValue) val).isInRange(low, high);
        } else {
            return false;
        }
    }
}