// For licensing, see: http://helium.knownspace.org/license.html

/**
 * AddEntityPoolEvent.java
 */
package org.datamanager.event;

import org.datamanager.event.ContainsEntityEvent;
import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.PoolEvent;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventGenerator;


/**
 * This event is fired when <code>Pool.add(Entity)</code>
 * is invoked.
 *
 * @author Matthew Farrellee
 */
public class AddEntityPoolEvent extends DataManagerEventAdapter
    implements PoolEvent, ContainsEntityEvent {
    /**
     * The <code>Entity</code> that was added.
     */
    private Entity addedEntity;

    /**
     * The public constructor used to create an
     * <code>AddEntityPoolEvent</code>.
     *
     * @param source The source of this event. Usually 'this.'
     * @param addedEntity The <code>Entity</code> that was added.
     */
    public AddEntityPoolEvent(EventGenerator source, Entity addedEntity) {
        super(source);
        this.addedEntity = addedEntity;
    }

    /**
     * Reports the new <code>Entity</code> that has been added to
     * the <code>Pool</code>.
     *
     * @return The <code>Entity</code> that was added.
     */
    public Entity getEntity() {
        return addedEntity;
    }

    /**
     * A toString() method to provide a meaningful <code>String</code>
     * representation of this event.
     *
     * @return A meaningful <code>String</code> representation
     *         of this event.
     */
    public String toString() {
        return "AddEntityPoolEvent[[source: " + source + "]" + 
               "[addedEntity: " + addedEntity + "]" + "[time: " + time + 
               "]]";
    }
}