// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.LinkEvent;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventGenerator;


/**
 * This event is fired when <code>Entity.attach()</code>
 * is invoked.
 *
 * @author Matthew Farrellee
 */
public class AttachLinkEvent extends DataManagerEventAdapter
    implements LinkEvent, ContainsEntityEvent {
    /**
     * The <code>Entity</code> that was attached.
     */
    private Entity attachedEntity;

    /**
     * The public constructor used to create an
     * <code>AttachLinkEvent</code>.
     *
     * @param source The source of this event. Usually 'this'.
     * @param attachedEntity The <code>Entity</code> that was attached.
     */
    public AttachLinkEvent(EventGenerator source, Entity attachedEntity) {
        super(source);
        this.attachedEntity = attachedEntity;
    }

    /**
     * Reports the <code>Entity</code> that was attached.
     *
     * @return The <code>Entity</code> that was attached.
     */
    public Entity getEntity() {
        return this.attachedEntity;
    }

    /**
     * A toString() method to provide a meaningful <code>String</code>
     * representation of this event.
     *
     * @return A meaningful <code>String</code> representation
     *         of this event.
     */
    public String toString() {
        return "AttachLinkEvent[[source: " + source + "]" + 
               "[attachedEntity: " + attachedEntity + "]" + "[time: " + time + 
               "]]";
    }
}