// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.LinkEvent;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventGenerator;


/**
 * This event is fired when <code>Entity.detach()</code>
 * is invoked.
 *
 * @author Matthew Farrellee
 */
public class DetachLinkEvent extends DataManagerEventAdapter
    implements LinkEvent, ContainsEntityEvent {
    /**
     * The <code>Entity</code> that was detached.
     */
    private Entity detachedEntity;

    /**
     * The public constructor used to create a
     * <code>DetachLinkEvent</code>.
     *
     * @param source The source of this event. Usually 'this.'
     * @param detachedEntity The <code>Entity</code> that was detached.
     */
    public DetachLinkEvent(EventGenerator source, Entity detachedEntity) {
        super(source);
        this.detachedEntity = detachedEntity;
    }

    /**
     * Reports the <code>Entity</code> that was detached.
     *
     * @return The <code>Entity</code> that was detached.
     */
    public Entity getEntity() {
        return this.detachedEntity;
    }

    /**
     * A toString() method to provide a meaningful <code>String</code>
     * representation of this event.
     *
     * @return A meaningful <code>String</code> representation
     *         of this event.
     */
    public String toString() {
        return "DetachLinkEvent[[source: " + source + "]" + 
               "[detachedEntity: " + detachedEntity + "]" + "[time: " + time + 
               "]]";
    }
}