// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.event;

import java.awt.Component;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.RequestEvent;

import org.datamanager.kernel.EventGenerator;


/**
 * This event notifies any interested EventHandlers that the GuiSimpleton
 * creator of the Component within <code>guiComponentInfo</code> would very
 * much like for that GuiComponent to be disposed of.  This is necessary as
 * AWT event handlers are currently installed within the GuiSimpleton creator
 * class, not by the GuiCollectorSimpleton that collects these GUI components,
 * and dispose() can only be invoked on top-level windowing components (I
 * think).
 *
 * @author Team Helium
 * @version $Revision: 1.3 $
 */
public class DisposeGuiRequestEvent extends DataManagerEventAdapter
    implements RequestEvent {
    private final Component componentToBeDisposed;

    public DisposeGuiRequestEvent(EventGenerator source, 
                                  Component componentToBeDisposed) {
        super(source);
        this.componentToBeDisposed = componentToBeDisposed;
    }

    public Component getComponentToBeDisposed() {
        return this.componentToBeDisposed;
    }

    public String toString() {
        return "DisposeGuiRequestEvent [" + "[source: " + source + 
               "] [time: " + time + "] [component: " + 
               componentToBeDisposed.getName() + "]";
    }
}

/*
 * $Log: DisposeGuiRequestEvent.java,v $
 * Revision 1.3  2002/12/20 20:52:24  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.2  2002/11/30 11:07:00  alllee
 * Modified these events to reflect changes to fix the bug sitting at
 * http://lazlo.bloomington.in.us:5224/helium/issue73
 *
 * ExportGuiRequestEvent no longer uses getIdentifier() in its toString method
 * because Identifiers were removed from GuiSimpletonInfo-s.  Identifiers ended
 * up becoming useless in the face of how difficult it would be to make them do
 * what they do - uniquely identify Gui Components so that dispose and export
 * requests dispatched by the GuiSimpleton were appropriately handled by the
 * GuiCollector.  This is now being done by passing around a pointer to the
 * original Component being exported and using the Component itself as a key
 * in a hashtable mapping to JInternalFrame-s.  This could become a potential
 * FIXME if it turns out that the native code implementation of hashCode() in
 * Object is causing lotsa collisions in the HashMap, and that those collisions
 * are causing performance problems, but that doesn't seem likely since there
 * aren't that many components being collected by the GuiCollector.  A job for
 * the Profiler in any case.
 *
 * DisposeGuiRequestEvent no longer carries a reference to a GuiSimpletonInfo --
 * it has a reference to the Component that should be disposed instead so that
 * the EmailGuiCollectorSimpleton can retrieve the JInternalFrame that needs to
 * be disposed from its HashMap of Component keys and JInternalFrame values.
 *
 * Some codebase-style-changed files committed also..
 *
 * Revision 1.1  2002/11/21 10:33:54  alllee
 * Refactoring GuiRequestEvents a bit (mostly name changes).  Added
 * DisposeGuiRequestEvent, which handles notifying GuiCollectorSimpletons that
 * a given GuiSimpleton wants to dispose its export()-ed Component.
 *
 */
