// For licensing, see: http://helium.knownspace.org/license.html

/**
 * EmailDisplayRequestEvent.java
 */
package org.datamanager.event;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.RequestEvent;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventGenerator;


/**
 * This event indicates that the user has requested the display of an email
 * message.
 *
 * @author Matt Liggett
 */
public class EmailDisplayRequestEvent extends DataManagerEventAdapter
    implements RequestEvent, ContainsEntityEvent {
    private Entity message;

    /**
     * Create a new EmailDisplayRequestEvent.
     *
     * @param message the Entity containing the message to display
     */
    public EmailDisplayRequestEvent(EventGenerator source, Entity message) {
        super(source);
        this.message = message;
    }

    /**
     * Get the Entity that contains the message to display.
     */
    public Entity getEntity() {
        return message;
    }

    public String toString() {
        return "(EmailDisplayRequestEvent (message " + message + "))";
    }
}

/*
 * $Log: EmailDisplayRequestEvent.java,v $
 * Revision 1.4  2002/12/20 20:52:24  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.3  2002/11/17 08:44:11  alllee
 * All Event classes that contain Entities now implement the ContainsEntityEvent
 * marker interface as well, which specifies the lone method getEntity().  This
 * means that we no longer need to have getSpecificallyNamedEntity() from a
 * particularly-typed event - we can just use
 * ((ContainsEntityEvent)event).getEntity() to acquire the Entity.  Of course,
 * further specifying the type will allow us to more strongly identify which
 * event we are handling.  Made some minor javadocs/comment changes as well.
 *
 * Revision 1.2  2002/10/31 01:26:42  mliggett
 * Fixed @author tag.
 *
 * Revision 1.1  2002/10/31 01:11:40  mliggett
 * Added EmailDisplayRequestEvent and a basic unit test for it.
 *
 */
