// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.event.DataManagerEventAdapter;

import org.datamanager.kernel.EventGenerator;


/**
 * This event indicates that the user has requested a search of Email Metadata,
 * such as From.
 *
 * @author Matt Liggett
 * @author Chris Dent
 */
public class EmailMetadataSearchEvent extends DataManagerEventAdapter {
    /** The string associated with the query. */
    private String queryString;

    /** The name of the field to query. */
    private String fieldName;

    /**
     * Creates a new EmailMetadataSearchEvent for initiating
     * a search for matching email metadata.
     *
     * @param metadataType the name of the field to query
     * @param queryString The string being matched
     */
    public EmailMetadataSearchEvent(EventGenerator source, String fieldName, 
                                    String queryString) {
        super(source);
        this.fieldName = fieldName;
        this.queryString = queryString;
    }

    public String getFieldName() {
        return fieldName;
    }

    public String getQueryString() {
        return queryString;
    }

    public String toString() {
        return "(EmailMetadataSearchEvent (fieldName " + fieldName + 
               ") (queryString " + queryString + "))";
    }
}

/*
 * $Log: EmailMetadataSearchEvent.java,v $
 * Revision 1.4  2002/12/20 20:52:24  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.3  2002/11/17 08:44:14  alllee
 * All Event classes that contain Entities now implement the ContainsEntityEvent
 * marker interface as well, which specifies the lone method getEntity().  This
 * means that we no longer need to have getSpecificallyNamedEntity() from a
 * particularly-typed event - we can just use
 * ((ContainsEntityEvent)event).getEntity() to acquire the Entity.  Of course,
 * further specifying the type will allow us to more strongly identify which
 * event we are handling.  Made some minor javadocs/comment changes as well.
 *
 * Revision 1.2  2002/11/16 20:06:44  mliggett
 * Very very minor reformattings.
 *
 * Revision 1.1  2002/11/03 08:06:42  cjdent
 *
 * First pass at an Event that requests an email metadata search. We fire one
 * of these from EmailDisplaySimpleton when you double click on a header
 * item. This will be picked up by the EmailMetadataSearchSimpleton (not
 * yet created). It is _quite_ likely that much of this work can be
 * eventually merged with the other *Search* Simpletons and Events.
 *
 * - Chris and Matt
 *
 *
 */
