// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.event.CollectorEvent;
import org.datamanager.event.ContainsEntityEvent;
import org.datamanager.event.DataManagerEventAdapter;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventGenerator;


/**
 * Objects of this class encapsulate a collection of parameters determining a 
 * network connection to a remote machine holding a mailbox for a particular user.
 * The parameters are: username, password, email host machine, email access
 * protocol (imap, pop3, smtp), and mailbox.  
 *
 * These parameters are enclosed within an Entity object.  
 * @author Team Helium
 * @version $Revision: 1.5 $
 **/
public class EmailParametersEnteredCollectorEvent
    extends DataManagerEventAdapter implements CollectorEvent,
                                               ContainsEntityEvent {
    private final Entity emailParametersEntity;

    /**
     * Initializes this event with its generator's reference and an Entity
     * containing the collected email parameters needed for connecting to a
     * specific email data store.
     **/
    public EmailParametersEnteredCollectorEvent(EventGenerator source, 
                                                Entity emailParametersEntity) {
        super(source);
        this.emailParametersEntity = emailParametersEntity;
    }

    /** 
     * Reports the entity contained within this event.
     */
    public Entity getEntity() {
        return this.emailParametersEntity;
    }

    /**
     * Reports a string representation of this event.
     * 
     **/
    public String toString() {
        return "EmailParametersEnteredCollectorEvent [[source: " + source + 
               "] [time: " + time + "] [EmailParametersEntity: " + 
               getEntity() + "]";
    }
}