// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.RequestEvent;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventGenerator;


/**
 * Event fired whenever a Simpleton has started to retrieve email.
 *
 * @author Team Helium
 * @version $Revision: 1.3 $
 */
public class EmailReplyRequestEvent extends DataManagerEventAdapter
    implements RequestEvent, ContainsEntityEvent {
    /** The Entity which needs replying. */
    private Entity messageEntity;

    public EmailReplyRequestEvent(EventGenerator source, Entity messageEntity) {
        super(source);
        this.messageEntity = messageEntity;
    }

    public Entity getEntity() {
        return this.messageEntity;
    }

    public String toString() {
        return "EmailReplyRequestEvent [" + "[source: " + source + 
               "] [messageEntity: " + messageEntity + "]]";
    }

    public boolean equals(Object object) {
        if (object instanceof EmailReplyRequestEvent) {
            EmailReplyRequestEvent emailReplyRequestEvent = 
                    (EmailReplyRequestEvent) object;

            return getEntity().equals(emailReplyRequestEvent.getEntity()) && 
                   source.equals(emailReplyRequestEvent.source);
        }

        return false;
    }

    public int hashCode() {
        // Guaranteed to return the same number if getMessageEntity() and source
        // are the same.
        return getEntity().hashCode() + source.hashCode();
    }
} // EmailReplyRequestEvent
/*
 *
 * $Log: EmailReplyRequestEvent.java,v $
 * Revision 1.3  2002/12/20 20:52:24  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.2  2002/11/17 08:44:14  alllee
 * All Event classes that contain Entities now implement the ContainsEntityEvent
 * marker interface as well, which specifies the lone method getEntity().  This
 * means that we no longer need to have getSpecificallyNamedEntity() from a
 * particularly-typed event - we can just use
 * ((ContainsEntityEvent)event).getEntity() to acquire the Entity.  Of course,
 * further specifying the type will allow us to more strongly identify which
 * event we are handling.  Made some minor javadocs/comment changes as well.
 *
 * Revision 1.1  2002/11/14 03:55:46  mliggett
 * Added EmailReplyRequestEvent and Tester.
 *
 * Ran codebase-style which probably caught way more crap than I wanted it to.
 *
 *
 */
