// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.event.ContainsEntityEvent;
import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.RequestEvent;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventGenerator;


/**
 * This event is used to notify any interested handlers that an Entity wants
 * to be displayed.  
 *
 * @author Team Helium
 * @version $Revision: 1.4 $
 */
public class EntityDisplayRequestEvent extends DataManagerEventAdapter
    implements RequestEvent, ContainsEntityEvent {
    private Entity entity;

    public EntityDisplayRequestEvent(EventGenerator source, Entity entity) {
        super(source);
        this.entity = entity;
    }

    /**
     * Gets the Entity that contains the message to display.
     */
    public Entity getEntity() {
        return this.entity;
    }

    /**
     * Returns a String representation of this Event.
     */
    public String toString() {
        return "(EntityDisplayRequestEvent (entity: " + entity + "))";
    }
} // EntityDisplayRequestEvent
/*
 * $Log: EntityDisplayRequestEvent.java,v $
 * Revision 1.4  2002/12/20 20:52:25  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.3  2002/11/17 08:44:15  alllee
 * All Event classes that contain Entities now implement the ContainsEntityEvent
 * marker interface as well, which specifies the lone method getEntity().  This
 * means that we no longer need to have getSpecificallyNamedEntity() from a
 * particularly-typed event - we can just use
 * ((ContainsEntityEvent)event).getEntity() to acquire the Entity.  Of course,
 * further specifying the type will allow us to more strongly identify which
 * event we are handling.  Made some minor javadocs/comment changes as well.
 *
 * Revision 1.2  2002/11/16 09:22:09  alllee
 * codebase-style, fixed/cleaned javadocs, and added implements RequestEvent type
 * marker.
 *
 * Revision 1.1  2002/11/16 09:17:09  alllee
 * Making the move to generic EntityDisplayRequestEvents instead of specific
 * EmailDisplayRequestEvent, MySocksDisplayRequestEvent,
 * RubberUnderwearDisplayRequestEvent, and so on.
 *
 */
