// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.event.DataManagerEventAdapter;

import org.datamanager.kernel.EventGenerator;
import org.datamanager.kernel.GuiSimpletonInfo;


/**
 * This event notifies interested GuiCollector subscribers that there is a
 * new Component to be added.  The Component is wrapped in a GuiSimpletonInfo
 * class that maintains additional Identification information about the
 * GuiSimpleton (currently a String name that may or may not be unique,
 * depending on whether or not the Component is allowed to have multiple
 * instances of itself).  This has not been fully implemented yet.  The
 * Identifier should probably be implemented as a GuiIdentifier class (or we
 * could conceivably re-use the Identifier class in the kernel, ughrk to that
 * though).
 *
 * @author Team Helium
 * @version $Revision: 1.3 $
 */
public class ExportGuiRequestEvent extends DataManagerEventAdapter
    implements CollectorEvent, RequestEvent {
    private GuiSimpletonInfo info;

    public ExportGuiRequestEvent(EventGenerator source, GuiSimpletonInfo info) {
        super(source);
        this.info = info;
    }

    /**
     * Returns the <code>GuiSimpletonInfo</code> being transmitted by this
     * event.
     * @see GuiSimpletonInfo
     */
    public GuiSimpletonInfo getGuiSimpletonInfo() {
        return this.info;
    }

    /**
     * Returns a <code>String</code> representation of this event.
     */
    public String toString() {
        return "ExportGuiRequestEvent [" + "[source: " + source + 
               "] [time: " + time + "] [GuiSimpletonName: " + 
               getGuiSimpletonInfo().getTitle() + "]";
    }
} // ExportGuiRequestEvent
