// For licensing, see: http://helium.knownspace.org/license.html

/**
 * NewsGroupDownloadRequestEvent.java
 */
package org.datamanager.event;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.RequestEvent;

import org.datamanager.kernel.EventGenerator;


/**
 * This event is used to trigger the download of a newsgroup.
 *
 * @author Matthew Farrellee
 */
public class NewsGroupDownloadRequestEvent extends DataManagerEventAdapter
    implements RequestEvent {
    private String group;
    private String server;

    /**
     * Create a new NewsGroupDownloadRequestEvent.
     *
     * @param source The source of the event.
     * @param group The new group to downloaded.
     * @param server The server on which to find the group.
     */
    public NewsGroupDownloadRequestEvent(EventGenerator source, String group, 
                                         String server) {
        super(source);
        this.group = group;
        this.server = server;
    }

    /**
     * Get the name of the newsgroup.
     */
    public String getNewsGroup() {
        return group;
    }

    /**
     * Get the name of the news server.
     */
    public String getServer() {
        return server;
    }

    public String toString() {
        return "NewsGroupDownloadRequestEvent[" + "[group: " + group + "]" + 
               "[server: " + server + "]" + "[source: " + source + "]" + 
               "[time: " + time + "]";
    }
}