// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.constraint.EntityConstraint;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.RequestEvent;

import org.datamanager.kernel.EventGenerator;


/**
 * SearchRequestEvent wraps an EntityConstraint through which a search handling
 * Simpleton may search the Pool.
 *
 * @author Team Helium
 * @version $Revision: 1.7 $
 */
public class SearchRequestEvent extends DataManagerEventAdapter
    implements RequestEvent {
    private EntityConstraint constraint;
    private String query;

    public SearchRequestEvent(EventGenerator source, 
                              EntityConstraint constraint, String query) {
        super(source);
        this.constraint = constraint;
        this.query = query;
    }

    /**
     * Returns the EntityConstraint wrapped by this Event.  The
     * EntityConstraint can be used to search() the Pool and is intended for
     * handlers of this Event.
     */
    public EntityConstraint getConstraint() {
        return this.constraint;
    }

    /**
     * Returns the String query used by the EntityConstraint wrapped by this
     * Event.
     */
    public String getQuery() {
        return query;
    }

    /**
     * Returns the String representation of this event.
     */
    public String toString() {
        return "SearchRequestEvent[[source: " + source + "]" + 
               "[constraint: " + constraint + "]" + "[time: " + time + "]]";
    }
} // SearchRequestEvent
/*
 * $Log: SearchRequestEvent.java,v $
 * Revision 1.7  2002/12/20 20:52:25  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.6  2002/11/17 08:44:15  alllee
 * All Event classes that contain Entities now implement the ContainsEntityEvent
 * marker interface as well, which specifies the lone method getEntity().  This
 * means that we no longer need to have getSpecificallyNamedEntity() from a
 * particularly-typed event - we can just use
 * ((ContainsEntityEvent)event).getEntity() to acquire the Entity.  Of course,
 * further specifying the type will allow us to more strongly identify which
 * event we are handling.  Made some minor javadocs/comment changes as well.
 *
 * Revision 1.5  2002/11/16 09:22:09  alllee
 * codebase-style, fixed/cleaned javadocs, and added implements RequestEvent type
 * marker.
 *
 */
