// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.event.CollectorEvent;
import org.datamanager.event.ContainsEntityEvent;
import org.datamanager.event.DataManagerEventAdapter;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventGenerator;


/**
 * This Event indicates that search results are available,
 * encapsulating an Entity containing the results
 * as attributes.
 *
 * @author Allen Lee
 * @version $Revision: 1.7 $
 */
public class SearchResultsFoundEvent extends DataManagerEventAdapter
    implements CollectorEvent, ContainsEntityEvent {
    private final Entity searchResultsEntity;

    public SearchResultsFoundEvent(EventGenerator source, Entity resultsEntity) {
        super(source);
        this.searchResultsEntity = resultsEntity;
    }

    /**
     * Reports the entity contained within this event.
     */
    public Entity getEntity() {
        return this.searchResultsEntity;
    }

    /**
     * Reports a <code>String</code> representation of the event.
     *
     * @return A meaningful <code>String</code> representation
     *         of this event.
     */
    public String toString() {
        return "SearchResultsFoundEvent [[source: " + getSource() + "]" + 
               "[SearchResultsEntity: " + getEntity() + "][time: " + 
               getTime() + "]]";
    }
} // SearchResultsFoundEvent
