// For licensing, see: http://helium.knownspace.org/license.html

/**
 * WebSearchRequestEvent.java
 */
package org.datamanager.event;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.RequestEvent;

import org.datamanager.kernel.EventGenerator;


/**
 * This event is used to trigger a web search. It has a
 * number of constants that should be used as the value
 * of "engine" in this class' constructor.
 *
 * @author Matthew Farrellee
 */
public class WebSearchRequestEvent extends DataManagerEventAdapter
    implements RequestEvent {
    /* Possible Search Engines that can be used. */

    // Their format should be such that keywords can
    // be appended to the end of their url.
    //    public static final String WEBCRAWLER =
    //        "http://web.webcrawler.com/d/search/p/" +
    //         "webcrawler/index.jhtml?c=web&s=";
    public static final String GOOGLE = "http://www.google.com/search?q=";

    //    public static final String EXCITE = "http://srch.excite.com/d/search/p/" +
    //                                        "excite/index.jhtml?c=web&s=";
    public static final String DEJANEWS = "http://groups.google.com/groups?q=";
    public static final String YAHOO = "http://search.yahoo.com/bin/search?p=";
    public static final String LYCOS = "http://search.lycos.com/default.asp?query=";
    public static final String ALTAVISTA = "http://altavista.com/sites/search/web?q=";
    private String engine;
    private String keywords;

    /**
     * The non-search engine specific constructor.
     * This constructor uses GOOGLE as the default engine.
     *
     * @param source The source of the event.
     * @param keywords The keywords with which to search.
     */
    public WebSearchRequestEvent(EventGenerator source, String keywords) {
        this(source, keywords, GOOGLE);
    }

    /**
     * The search engine specific consructor.
     * This constructor allows you to speficy which search
     * engine should be used in the search. The engine should
     * be one of the constants provided on this class.
     *
     * @param source The source of the event.
     * @param keywords The keywords with which to search.
     * @param engine The search engine to use for the search.
     */
    public WebSearchRequestEvent(EventGenerator source, String keywords, 
                                 String engine) {
        super(source);
        this.engine = engine;
        this.keywords = keywords;
    }

    /**
     * Get a string representation of the search engine's
     * url that is used for this search event.
     */
    public String getEngine() {
        return engine;
    }

    /**
     * Get the keywords used for this search event.
     */
    public String getKeywords() {
        return keywords;
    }

    /**
     * Get a String representation of this event.
     */
    public String toString() {
        return "WebSearchRequestEvent[" + "[engine: " + engine + "]" + 
               "[keywords: " + keywords + "]" + "[time: " + time + "]" + "]";
    }
}