// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.kernel;

import com.coyotegulch.jisp.KeyObject;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;


public class ComparableIdentifier extends KeyObject {
    private static long previousMillSecond = 0;
    private static long nanoSecondCounter = 0;
    private long millSecond;
    private long nanoSecond;

    public ComparableIdentifier() {
        millSecond = System.currentTimeMillis();
        nanoSecondCounter++;

        if (millSecond != previousMillSecond) {
            nanoSecondCounter = 0;
        }

        nanoSecond = nanoSecondCounter;
        previousMillSecond = millSecond;
    }

    public int compareTo(KeyObject keyObject) {
        ComparableIdentifier comparableIdentifier = (ComparableIdentifier) keyObject;

        if (millSecond == comparableIdentifier.millSecond) {
            return (int) (nanoSecond - comparableIdentifier.nanoSecond);
        } else {
            return (int) (millSecond - comparableIdentifier.millSecond);
        }
    }

    //I am not sure why NullKey need the max value. I just follow the LongKey source to give the max value
    public KeyObject makeNullKey() {
        ComparableIdentifier nullKey = new ComparableIdentifier();
        nullKey.millSecond = 0xFFFFFFFFFFFFFFFFL;
        nullKey.nanoSecond = 0xFFFFFFFFFFFFFFFFL;

        return nullKey;
    }

    public void writeExternal(ObjectOutput out) throws IOException {
        //out.writeObject(new ComparableIdentifier(millSecond,nanoSecond));
        out.writeObject(new Long(this.millSecond));
        out.writeObject(new Long(this.nanoSecond));
    }

    public void readExternal(ObjectInput in) throws IOException, 
                                                    ClassNotFoundException {
        millSecond = ((Long) (in.readObject())).longValue();
        nanoSecond = ((Long) (in.readObject())).longValue();
    }
}