// For licensing, see: http://helium.knownspace.org/license.html
//
//Modified (10/10/2002): maa
//1) Cleaned up the JavaDoc a bit.
//
package org.datamanager.kernel;

import org.datamanager.constraint.EventConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.EventHandler;


/**
 * EventGenerators are able to generate events.  Their
 * natural collaborators are EventHandlers that can subscribe to them
 * specifying a constraint to indicate which events interest them.
 *
 * @author Matthew Farrellee
 */
public interface EventGenerator {
    /**
     * Subscribe an EventHandler with an EventConstraint.
     *
     * @param handler The EventHandler that will observe the events.
     * @param constraint The constraint that identifies the events of interest
     * to the EventHandler.
     *
     * @throws DataManagerException
     */
    public abstract void subscribe(EventHandler handler, 
                                   EventConstraint constraint)
                            throws DataManagerException;

    /**
     * Unsubscribe an EventHandler.
     *
     * @param handler The EventHandler to unsubscribe.
     *
     * @throws DataManagerException
     */
    public abstract void unsubscribe(EventHandler handler)
                              throws DataManagerException;
}