// For licensing, see: http://helium.knownspace.org/license.html
//
//Modified (10/06/2002): nab
//1) Altered code to use method references rather than instances variables.
//2) Fixed up the documentation.
//3) Made the constants Capitalized (Rename Field Reforing).
//4) Gave the instance variables more descriptive names (Rename Field Reforing).
//
//Modified (10/10/2002): maa
//1) Cleaned up the JavaDoc a bit.
//
package org.datamanager.kernel;

import org.datamanager.event.DataManagerEvent;

import org.datamanager.kernel.DataManagerWorker;
import org.datamanager.kernel.EventHandler;
import org.datamanager.kernel.Simpleton;


/**
 * This Simpleton works on EventHandlers and DataManagerEvents.
 * It takes an EventHandler and executes its handle() method,
 * passing the DataManagerEvent that is being handled.
 *
 * @author Matthew Farrellee
 */
class EventHandlerThread extends Simpleton {
    /**
     * Simpleton.Information about the EventHandlerThread.
     */
    private static final String CLASS_NAME = "org.datamanager.kernel.EventHandlerThread";
    private static final String NAME = "EventHandlerThread";
    private static final String SHORT_DESCRIPTION = "Runs EventHandlers.";
    private static final String LONG_DESCRIPTION = "Runs EventHandler.handle() methods.";
    private static final String VERSION = "Hydrogen";
    private static final String[] AUTHORS = { "Matthew Farrellee" };

    /**
     * The EventHandler who will have its handle() method run.
     */
    private EventHandler eventHandler;

    /**
     * The DataManagerEvent that will be passed to the
     * EventHandler's handle() method.
     */
    private DataManagerEvent dataManagerEvent;

    /**
     * Create a new EventHandlerThread.
     *
     * @param handler The EventHandler whose handle() will be called.
     * @param event The event to pass to the EventHandler.
     */
    EventHandlerThread(EventHandler eventHandler, 
                       DataManagerEvent dataManagerEvent) {
        this.eventHandler = eventHandler;
        this.dataManagerEvent = dataManagerEvent;

        setInformation(
                new Simpleton.Information(CLASS_NAME, NAME, SHORT_DESCRIPTION, 
                                          LONG_DESCRIPTION, VERSION, AUTHORS, 
                                          false, false, null));
    }

    /**
     * Execute the EventHandler's handle() method,
     * passing the DataManagerEvent that is being handled.
     */
    public void process() {
        getEventHandler().handle(getDataManagerEvent());
    }

    /**
     * Request a String representation of the EventHandlerThread.
     *
     * @return A String representation of the EventHandlerThread.
     */
    public String toString() {
        return "EventHandlerRunner[" + "[handler: " + getEventHandler() + 
               "]" + "[event: " + getDataManagerEvent() + "]" + "]";
    }

    /**
     * Get the EventHandler that is going to be run by the
     * EventHandlerThread.
     *
     * @return The EventHandler whose handle() will be run.
     */
    protected EventHandler getEventHandler() {
        return eventHandler;
    }

    /**
     * Get the DataManagerEvent that is being handled.
     *
     * @return The DataManagerEvent being handled.
     */
    protected DataManagerEvent getDataManagerEvent() {
        return dataManagerEvent;
    }
}