// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.kernel;

import java.awt.Component;
import java.awt.Rectangle;

import org.datamanager.event.DisposeGuiRequestEvent;
import org.datamanager.event.ExportGuiRequestEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.GuiSimpletonInfo;
import org.datamanager.kernel.Simpleton;

import org.datamanager.tools.kernelproxy.KernelProxy;


/**
 *
 * This is the superclass of all Simpletons that can export() a GUI component
 * via the ExportGuiRequestEvent.
 *
 * @author Team Helium
 * @version $Revision: 1.10 $
 */
public abstract class GuiSimpleton extends Simpleton {
    /**
     * Exports this GuiSimpleton's Component by firing a ExportGuiRequestEvent into
     * the Pool containing a new GuiSimpletonInfo.
     */
    public final void exportComponent(final Component exportedComponent) {
        // FIXME: should the default bounds of a GuiSimpleton component be
        // stuck in here instead of being known by the Collector?
        exportComponent(exportedComponent, null);
    }

    public final void exportComponent(final Component exportedComponent, 
                                      final Rectangle bounds) {
        if (exportedComponent != null) {
            // FIXME: In the future, we might not want to use the
            // exportedComponent's name as the Title..
            fireExportGuiRequestEvent(
                    new GuiSimpletonInfo(exportedComponent, 
                                         exportedComponent.getName(), bounds));
        }
    }

    private void fireExportGuiRequestEvent(final GuiSimpletonInfo guiSimpletonInfo) {
        try {
            Pool.getDefaultPool()
                .add(new ExportGuiRequestEvent(Pool.getDefaultPool(), 
                                               guiSimpletonInfo));
        } catch (DataManagerException exception) {
            exception.printStackTrace();
            throw new RuntimeException(exception);
        }
    }

    public final void dispose(final Component componentToBeDisposed) {
        try {
            componentToBeDisposed.getParent().setVisible(false);
            KernelProxy.getInstance()
                       .addEvent(new DisposeGuiRequestEvent(
                                         KernelProxy.getInstance()
                                                    .getEventGenerator(), 
                                         componentToBeDisposed));
        } catch (DataManagerException exception) {
            //FIXME: whoa nelly, what to do about error handling
            exception.printStackTrace();
            throw new RuntimeException(exception);
        }
    }
} // GuiSimpleton
/*
 * $Log: GuiSimpleton.java,v $
 * Revision 1.10  2002/12/20 20:52:31  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.9  2002/12/02 05:29:38  alllee
 * GuiSimpleton uses the exported Component's getName() as its title now to allow
 * for specific email reply display frames (which are all exported by a single
 * BasicEmailReplySimpleton) having titles specific to the email message's
 * subject being replied to.  It's hacky, and not well documented, yet.
 * Basically, if you wish to have a GuiSimpleton's exported component publish the
 * title to be used with its JInternalFrame representation within a GuiCollector,
 * you have to setName() the component-to-be-exported to the String title that
 * you wish to use.  This may not be optimal for future developers, but it works
 * for now, which I think is what we are aiming for while concentrating on Jisp
 * and clustering.
 *
 * Revision 1.8  2002/11/30 11:07:30  alllee
 * *** empty log message ***
 *
 */
