// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.kernel;

import java.awt.Component;
import java.awt.Rectangle;


/**
 *
 * This class contains references to pertinent information about a
 * GuiSimpleton.  The Component being exported is publicly accessible so
 * that the GuiCollector collecting these GuiSimpletonS can maintain a mapping
 * between Components pointers - this is necessary so that the GuiSimpletonS
 * can install event handlers within the exported component that let the
 * Collector know that it should dispose() of whatever component it has
 * generated on its end encapsulating the exported Component.
 * 
 * @author Team Helium
 * @version $Revision: 1.8 $
 */
public final class GuiSimpletonInfo {
    private final Component component;
    private final Rectangle preferredBound;
    private final String title;

    public GuiSimpletonInfo(Component component, String componentTitle) {
        this(component, componentTitle, null);
    }

    public GuiSimpletonInfo(Component component, String componentTitle, 
                            Rectangle preferredBound) {
        this.component = component;
        this.title = componentTitle;
        this.preferredBound = preferredBound;
    }

    public final Component getComponent() {
        return this.component;
    }

    public final Rectangle getPreferredBound() {
        return this.preferredBound;
    }

    public final String getTitle() {
        return this.title;
    }
} // GuiSimpletonInfo
/*
 * $Log: GuiSimpletonInfo.java,v $
 * Revision 1.8  2002/12/20 20:52:31  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.7  2002/11/30 11:07:30  alllee
 * *** empty log message ***
 *
 * Revision 1.6  2002/11/24 07:45:42  alllee
 * Overly hasty commit, fixed ordering of final member initialization.
 *
 * Revision 1.5  2002/11/24 07:40:04  alllee
 * Minor speling fix.
 *
 */
