// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.kernel;

import java.io.Serializable;

import org.datamanager.kernel.Identifier;


/**
 * The JispIdentifierManager class is a source of unique Identifiers for use
 * with the JispEntityManager.
 */
class JispIdentifierManager implements Serializable {
    /** The only instance of the JispIdentifierManager class. */
    private static JispIdentifierManager instance = new JispIdentifierManager();

    /**
     * The default constructor.  It is private because JispIdentifierManager is
     * a singleton.
     */
    private JispIdentifierManager() {
    }

    /**
     * Returns the Singleton instance of the JispIdentifierManager.
     */
    public static JispIdentifierManager getInstance() {
        return instance;
    }

    /**
     * Returns the next available unique identifier.
     */
    public static JispIdentifier getIdentifier() {
        return JispIdentifier.generateIdentifier();
    }
}

/*
 *
 * $Log: JispIdentifierManager.java,v $
 * Revision 1.2  2002/12/20 20:52:31  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.1  2002/12/03 05:04:30  mliggett
 * First stab at pure, jisp-only storage.  Obviously needs refactoring (which
 * will shorten the longer source files substantially) and a
 * looksee at the javadoc.  Separate message to be sent fully
 * explaining things, but these entities keep NO data in main memory.  All
 * four pieces of Entity data (name, value, attributes and bases) are kept in
 * separate indexed jisp databases and the contents are loaded on demand.
 *
 * Includes several unit tests.  Caching EntityManager to be checked in
 * next.
 *
 *
 */
