// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.kernel;

import java.io.File;
import java.io.InputStream;
import java.io.OutputStream;

import org.datamanager.persistence.DataAccessObject;
import org.datamanager.persistence.DataAccessObjectFactory;


/**
 * Persistable interface that datamanager persistable objects
 * implement. Provides access to the persist() method and
 * static fields necessary for persistence.
 *
 * @version $Revision: 1.9 $
 *
 */
public interface Persistable {
    /** Folder in which persisted objects are placed. */
    static final String PERSISTENCE_FOLDER = ".helium";

    /** Persistence layer factory */
    static final DataAccessObjectFactory PERSISTENCE_FACTORY = 
            DataAccessObjectFactory.newInstance();

    //FIXME:xirao:replace this for jisp index persistence purpose
    //static final DataAccessObject PERSISTER = PERSISTENCE_FACTORY.getDataAccessObject(
    //                                                  DataAccessObjectFactory.SERIALIZABLE_PERSISTENCE);

    /**
     * Persistence layer persister object.  Currently using XML-styled
     * persistence.
     */
    static final DataAccessObject PERSISTER = PERSISTENCE_FACTORY.getDataAccessObject(
                                                      DataAccessObjectFactory.JISP_INDEX_PERSISTENCE);

    /**
     * Persists this persistable object to the location specified by File.
     *
     * @param File Writes this object to the specified File
     */
    void persist(File location);

    /**
     * Persists this persistable object to the given OutputStream
     *
     * @param OutputStream Writes this to the given OutputStream
     */
    void persist(OutputStream outputStream);
} // Persistable
