// For licensing, see: http://helium.knownspace.org/license.html

/**
 * IntegerEntityValue.java
 * @author Benjamin Keil
 *
 * Created 199910252056
 */
package org.datamanager.passiveentityvalue;

import org.datamanager.kernel.EntityValue;

import org.datamanager.tools.Debug;


/**
 * IntegerEntityValue should give us all the functionality we need for working
 * with integer values.  More explicit documentation given at NumberEntityValue
 *
 * @see NumberEntityValue
 */
public class IntegerEntityValue extends NumberEntityValue {
    private int value;

    /**
     * The default value for IntegerEntityValue is 0
     */
    public IntegerEntityValue() {
        this(0);
    }

    /**
      * Create an IntegerEntityValue with the indicated value.
      */
    public IntegerEntityValue(int value) {
        this.value = value;
    }

    public int hashCode() {
        return value;
    }

    ///////////////////////////////////////////////////////////////////////////
    //                                                                       //
    //                             Conversions                               //
    //                                                                       //
    ///////////////////////////////////////////////////////////////////////////
    // ----------------------     To Integer      -----------------------------

    /**
     * The nearest int is the value stored.
     */
    public int getNearestInt() {
        return value;
    }

    /**
      * The floor is the greatest integer less than or equal to the stored
      * value, or the stored value itself in this case.
      */
    public int getFloor() {
        return value;
    }

    /**
      * The ceiling is the lowest integer greater than or equal to the stored
      * value, or the stored value itself in this case.
      */
    public int getCeiling() {
        return value;
    }

    // ----------------------     To Double      ------------------------------
    public double getNearestDouble() {
        return (double) value;
    }

    // ----------------------      To String     ------------------------------
    public String toString() {
        return "IntegerEntityValue[" + value + "]";
    }

    //////////////////////////////////////////////////////////////////////////
    // These methods allow Integer and DoubleEntityValues to share a lot of
    // code.
    //////////////////////////////////////////////////////////////////////////
    double getValue() {
        return (double) value;
    }

    void setValue(double value) {
        this.value = (int) value;
    }

    ///////////////////////////////////////////////////////////////////////////
    // These methods are added specifically for sO, but will probably be     //
    // necessary for whatever oodb we use.                                   //
    ///////////////////////////////////////////////////////////////////////////
    protected int DBGetValue() {
        return value;
    }

    protected void DBSetValue(int value) {
        this.value = value;
    }
} // DoubleEntityValue
