// For licensing, see: http://helium.knownspace.org/license.html

/**
 * NumericEntityValue.java
 * @author Benjamin Keil
 *
 * Created 199910071548
 */
package org.datamanager.passiveentityvalue;

/**
 * NumericEntityValue is an interface that provides for a common working
 * all numerical types, that is rational numbers, integers, and whatever
 * else we can come up with.
 */
public abstract interface NumericEntityValue extends PassiveEntityValue,
                                                     Comparable {
    ///////////////////////////////////////////////////////////////////////////
    //                                                                       //
    //                          Comparisons                                  //
    //                                                                       //
    ///////////////////////////////////////////////////////////////////////////
    public abstract boolean isInRange(NumericEntityValue low, 
                                      NumericEntityValue high);

    public abstract boolean isInRange(double low, double high);

    public abstract boolean isGreaterThan(NumericEntityValue low);

    public abstract boolean isGreaterThan(double low);

    public abstract boolean isGreaterThanOrEqualTo(NumericEntityValue low);

    public abstract boolean isGreaterThanOrEqualTo(double low);

    public abstract boolean isLesserThan(NumericEntityValue high);

    public abstract boolean isLesserThan(double high);

    public abstract boolean isLesserThanOrEqualTo(NumericEntityValue high);

    public abstract boolean isLesserThanOrEqualTo(double high);

    public abstract boolean equals(NumericEntityValue n);

    public abstract boolean equals(double d);

    public abstract boolean equals(Object o);

    public abstract int compareTo(NumericEntityValue n);

    public abstract int compareTo(Object o);

    ///////////////////////////////////////////////////////////////////////////
    //                                                                       //
    //                             Conversions                               //
    //                                                                       //
    ///////////////////////////////////////////////////////////////////////////
    public abstract int getNearestInt();

    public abstract int getFloor();

    public abstract int getCeiling();

    public abstract double getNearestDouble();

    public abstract String toString();

    //////////////////////////////////////////////////////////////////////////
    //                                                                      //
    //                              Arithmetic                              //
    //                                                                      //
    //////////////////////////////////////////////////////////////////////////
    public abstract void add(NumericEntityValue addend);

    public abstract void add(double addend);

    public abstract void subtract(NumericEntityValue subtrahend);

    public abstract void subtract(double subtrahend);

    public abstract void multiplyBy(NumericEntityValue multiplier);

    public abstract void multiplyBy(double multiplier);

    public abstract void divideBy(NumericEntityValue divisor);

    public abstract void divideBy(double divisor);
}