// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.persistence;

import org.datamanager.persistence.serializable.SerializableDataAccessObject;


/**
 * A Factory for creating DataAccessObjects.
 *
 * @author xi rao & Jason Lynn Baumgartner
 */
public class DataAccessObjectFactory {
    public static final int XML_PERSISTENCE = 1;
    public static final int SERIALIZABLE_PERSISTENCE = 2;
    public static final int JISP_INDEX_PERSISTENCE = 3;
    private static final DataAccessObjectFactory INSTANCE = 
            new DataAccessObjectFactory();

    private DataAccessObjectFactory() {
    }

    /**
     * return an instance of DataAccessObjectFactory follow the singleton pattern
     * @return DataAccessObjectFactory instance of DataAccessObjectFactory
     */
    public static DataAccessObjectFactory newInstance() {
        return INSTANCE;
    }

    /**
     * return XMLDataAccessObject for client to use for save and restore the object follow xml format
     * @param persistenceType int type of the DataAccessObject
     * @return XMLDataAccessObject an instace of XMLDataAccessObject for save/retore the object as xml format
     */
    public DataAccessObject getDataAccessObject(int persistenceType) {
        //if (XML_PERSISTENCE == persistenceType) {
        //    return new XMLDataAccessObject();
        //} else
        if (SERIALIZABLE_PERSISTENCE == persistenceType) {
            return new SerializableDataAccessObject();
        }

        if (JISP_INDEX_PERSISTENCE == persistenceType) {
            return new SerializableDataAccessObject();
        }

        return null;
    }
}