// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.simpleton;

import org.datamanager.clustering.matrix.DocumentTermMatrix;
import org.datamanager.clustering.matrix.DocumentTermMatrixImpl;

import org.datamanager.constraint.EventConstraint;
import org.datamanager.constraint.EventTypeIsConstraint;

import org.datamanager.event.AddEntityPoolEvent;
import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventHandler;
import org.datamanager.kernel.GuiSimpleton;
import org.datamanager.kernel.Pool;

import org.datamanager.passiveentityvalue.WordFrequencyMapEntityValue;

import org.datamanager.tools.Debug;
import org.datamanager.tools.Toolbox;


/**
 * This simpletion will handle the AddEntityPoolEvent. If the entity is a
 * Email Event, it will try to get its WordFrequencyyMapEntityValue and add these
 * word, entity, word's frequency into DocumentTermMatrix
 */
public class DocumentTermMatrixBuilderSimpleton extends GuiSimpleton
    implements EventHandler {
    private Pool pool;
    private DocumentTermMatrix docTermMatrix;

    public void process() {
        try {
            pool = Pool.getDefaultPool();

            EventConstraint eventConstraint = new EventTypeIsConstraint(
                                                      AddEntityPoolEvent.class);
            pool.subscribe(this, eventConstraint);
        } catch (Exception everything) {
            everything.printStackTrace();
        }

        docTermMatrix = (DocumentTermMatrix) DocumentTermMatrixImpl.getDocumentTermMatrix();
    }

    public void handle(DataManagerEvent dataManagerEvent) {
        Entity entity = ((AddEntityPoolEvent) dataManagerEvent).getEntity();
        WordFrequencyMapEntityValue mapEntityValue;

        try {
            mapEntityValue = (WordFrequencyMapEntityValue) Toolbox.getFirstAttributeNamed(
                                                                   entity, 
                                                                   WordFrequencyMapEntityValue.ATTRIBUTE_NAME)
                                                                  .getValue();
            docTermMatrix.addWords(entity, mapEntityValue);
        } catch (DataManagerException exception) {
            Debug.writeLogMessage("error in kernel");
        } catch (NullPointerException exception) {
            // this entity don't have WordFrequencyMapEntityValue, so we simply
            // ingore this event
        }
    }
}