// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.simpleton;

import java.awt.BorderLayout;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.WindowConstants;

import org.datamanager.constraint.AndEventConstraint;
import org.datamanager.constraint.AttributeStringMatchConstraint;
import org.datamanager.constraint.EntityConstraint;
import org.datamanager.constraint.EventConstraint;
import org.datamanager.constraint.EventContainsEntityConstraint;
import org.datamanager.constraint.EventTypeIsConstraint;

import org.datamanager.event.DataManagerEvent;
import org.datamanager.event.EmailMetadataSearchEvent;
import org.datamanager.event.EmailReplyRequestEvent;
import org.datamanager.event.EntityDisplayRequestEvent;
import org.datamanager.event.LaunchBrowserWithURLEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventHandler;
import org.datamanager.kernel.GuiSimpleton;
import org.datamanager.kernel.Pool;
import org.datamanager.kernel.Simpleton;

import org.datamanager.simpleton.EmailMessageEntityHelper;

import org.datamanager.tools.Debug;
import org.datamanager.tools.kernelproxy.KernelProxy;


/**
 * Provides a GUI with a button to initiate the comosition of
 * a new mail message.
 */
public class EmailCompositionInitiatorSimpleton extends GuiSimpleton {
    /** Helper object encapsulating data access into an email message. */
    private EmailMessageEntityHelper messageHelper;

    /**
     * Runs this Simpleton. Makes an empty message entity to
     * which replies can be faked and then makes a button to
     * click to initiate a new message.
     */
    public void process() {
        makeMessage();
        makePanel();
    }

    /**
     * Makes the GUI panel for displaying a the button
     */
    private void makePanel() {
        JPanel panel = new JPanel();
        panel.setName("Compose New Email");
        panel.add(new JButton(makeComposeAction()));
        super.exportComponent(panel, new Rectangle(200, 250, 145, 125));
    }

    /**
     * Create an empty email message that can be used
     * to start a new message.
     */
    private void makeMessage() {
        try {
            messageHelper = new EmailMessageEntityHelper();
        } catch (DataManagerException exception) {
            Debug.writeLogMessage("Unable to create empty message helper: " + 
                                  exception);
            throw new RuntimeException(exception);
        }
    }

    /**
     * Creates an Action that fires an EmailReplyRequestEvent pointing to the
     * email message displayed by this EmailDisplaySimpleton.
     */
    private Action makeComposeAction() {
        return new AbstractAction("Compose New") {
            public void actionPerformed(ActionEvent event) {
                try {
                    KernelProxy.getInstance()
                               .addEvent(new EmailReplyRequestEvent(
                                                 KernelProxy.getInstance()
                                                            .getEventGenerator(), 
                                                 messageHelper.getMessage()));
                } catch (DataManagerException exception) {
                    // FIXME: usual bogus exception handling
                    throw new RuntimeException(exception);
                }
            }
        };
    }
}

/*
 * $Log: EmailCompositionInitiatorSimpleton.java,v $
 * Revision 1.7  2002/12/20 20:52:38  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.6  2002/12/11 08:39:21  cjdent
 *
 * Adjusted the default layout of the various GuiCollector components and the
 * collector itself to be a larger window with things more tightly
 * packed. For the sake of the demo and also because with touchgraph
 * in there we need more space.
 *
 * Revision 1.5  2002/12/02 06:24:44  alllee
 * Removed spurious getTitle() declarations and some codebase-style..
 *
 */
