// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.simpleton;

import java.awt.Component;

import org.datamanager.kernel.Entity;


/**
 * Displays an optionally-editable email message in an unspecified JComponent
 * onscreen.
 */
public interface EmailMessageComponent {
    /**
     * Sets whether or not this EmailMessageComponent should allow editing of
     * the contained message.
     */
    public void setEditable(boolean isEditable);

    /**
     * Returns true if this EmailMessageComponent allows editing of the
     * contained message; false otherwise.
     */
    public boolean isEditable();

    /**
     * Sets the message to display in this EmailMessageComponent.
     */
    public void setMessage(Entity message);

    /**
     * Gets the message displayed in this EmailMessageComponent.
     */
    public Entity getMessage();

    /**
     * Gets a Component which contains a graphical display of this message.
     */
    public Component getComponent();

    /**
     * Returns the Component which contains the contents of the <code>To:</code>
     * field, or <code>null</code> if it is not displayed.
     */
    public Component getToComponent();

    /**
     * Returns the Component which contains the contents of the <code>Cc:</code>
     * field, or <code>null</code> if it is not displayed.
     */
    public Component getCcComponent();

    /**
     * Returns the Component which contains the contents of the
     * <code>From:</code> field, or <code>null</code> if it is not displayed.
     */
    public Component getFromComponent();

    /**
     * Returns the Component which contains the contents of the
     * <code>Subject:</code> field, or <code>null</code> if it is not displayed.
     */
    public Component getSubjectComponent();

    /**
     * Returns the Compenent which contains the contents of the
     * <code>Date:</code> field, or <code>null</code> if it is not displayed.
     */
    public Component getDateComponent();
}

/*
 * $Log: EmailMessageComponent.java,v $
 * Revision 1.4  2002/12/20 20:52:38  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.3  2002/11/16 18:45:17  mliggett
 * Added methods to request the components that are handling To: From:, etc.
 * display to the EmailMessageComponent interface.
 *
 * Using those, extracted the metadata search code from
 * BasicEmailMessageComponent back into EmailDisplaySimpleton, so that
 * BasicEmailMessageComponent is more generic.
 *
 * Revision 1.2  2002/11/16 18:19:35  mliggett
 * Changed getComponent from JComponent to Component to make more general.
 *
 * Revision 1.1  2002/11/16 17:38:35  mliggett
 * Interface and basic implementation for displaying a single email message
 * onscreen.
 *
 * Basic implementation was factored out of EmailDisplaySimpleton.
 *
 */
