// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.simpleton;

import com.touchgraph.graphlayout.Edge;
import com.touchgraph.graphlayout.Node;
import com.touchgraph.graphlayout.TGException;
import com.touchgraph.graphlayout.TGPanel;
import com.touchgraph.graphlayout.interaction.DragNodeUI;
import com.touchgraph.graphlayout.interaction.LocalityScroll;
import com.touchgraph.graphlayout.interaction.TGAbstractClickUI;
import com.touchgraph.graphlayout.interaction.TGAbstractDragUI;
import com.touchgraph.graphlayout.interaction.TGUserInterface;

// FIXME: stop eating my food, you're so hungry!
import java.awt.event.*;

import javax.swing.*;
import javax.swing.event.*;

import org.datamanager.event.EntityDisplayRequestEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;

import org.datamanager.simpleton.TouchgraphEntityDisplayPanel;
import org.datamanager.simpleton.TouchgraphEntityNode;

import org.datamanager.tools.Debug;
import org.datamanager.tools.kernelproxy.KernelProxy;


/**
 * EntityNavigateUI extends the Touchgraph user interface
 * GLNavigateUI to provide a way of display Entities in
 * Knownspace and firing display events at the appropriate
 * time.
 */
public class EntityNavigateUI extends TGUserInterface {
    private TouchgraphEntityDisplayPanel entityDisplayPanel;
    private TGPanel tgPanel;
    private EntityNavigateMouseListener ml;
    private EntityNavigateMouseMotionListener mm;
    private TGAbstractDragUI hvDragUI;
    private TGAbstractDragUI rotateDragUI;
    private TGAbstractClickUI hvScrollToCenterUI;
    private DragNodeUI dragNodeUI;
    private LocalityScroll localityScroll;
    private JPopupMenu nodePopup;
    private JPopupMenu edgePopup;
    private Node popupNode;
    private Edge popupEdge;

    public EntityNavigateUI(TouchgraphEntityDisplayPanel entityDisplayPanel) {
        this.entityDisplayPanel = entityDisplayPanel;
        tgPanel = entityDisplayPanel.getTGPanel();

        localityScroll = entityDisplayPanel.getLocalityScroll();
        hvDragUI = entityDisplayPanel.getHVScroll().getHVDragUI();
        rotateDragUI = entityDisplayPanel.getRotateScroll().getRotateDragUI();
        hvScrollToCenterUI = entityDisplayPanel.getHVScroll()
                                               .getHVScrollToCenterUI();
        dragNodeUI = new DragNodeUI(tgPanel);

        ml = new EntityNavigateMouseListener();
        mm = new EntityNavigateMouseMotionListener();
        setUpNodePopup();
        setUpEdgePopup();
    }

    public void activate() {
        tgPanel.addMouseListener(ml);
        tgPanel.addMouseMotionListener(mm);
    }

    public void deactivate() {
        tgPanel.removeMouseListener(ml);
        tgPanel.removeMouseMotionListener(mm);
    }

    private void setUpNodePopup() {
        nodePopup = new JPopupMenu();

        JMenuItem menuItem;

        menuItem = new JMenuItem("Expand Node");

        ActionListener expandAction = new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                if (popupNode != null) {
                    tgPanel.expandNode(popupNode);
                }
            }
        };

        menuItem.addActionListener(expandAction);
        nodePopup.add(menuItem);

        menuItem = new JMenuItem("Collapse Node");

        ActionListener collapseAction = new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                if (popupNode != null) {
                    tgPanel.collapseNode(popupNode);
                }
            }
        };

        menuItem.addActionListener(collapseAction);
        nodePopup.add(menuItem);

        menuItem = new JMenuItem("Hide Node");

        ActionListener hideAction = new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                if (popupNode != null) {
                    tgPanel.hideNode(popupNode);
                }
            }
        };

        menuItem.addActionListener(hideAction);
        nodePopup.add(menuItem);

        nodePopup.addPopupMenuListener(new PopupMenuListener() {
            public void popupMenuCanceled(PopupMenuEvent e) {
            }

            public void popupMenuWillBecomeInvisible(PopupMenuEvent e) {
                tgPanel.setMaintainMouseOver(false);
                tgPanel.setMouseOverN(null);
                tgPanel.repaint();
            }

            public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
            }
        });
    }

    private void setUpEdgePopup() {
        edgePopup = new JPopupMenu();

        JMenuItem menuItem;

        menuItem = new JMenuItem("Hide Edge");

        ActionListener hideAction = new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                if (popupEdge != null) {
                    tgPanel.hideEdge(popupEdge);
                }
            }
        };

        menuItem.addActionListener(hideAction);
        edgePopup.add(menuItem);

        edgePopup.addPopupMenuListener(new PopupMenuListener() {
            public void popupMenuCanceled(PopupMenuEvent e) {
            }

            public void popupMenuWillBecomeInvisible(PopupMenuEvent e) {
                tgPanel.setMaintainMouseOver(false);
                tgPanel.setMouseOverE(null);
                tgPanel.repaint();
            }

            public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
            }
        });
    }

    class EntityNavigateMouseMotionListener extends MouseMotionAdapter {
        public void mouseMoved(MouseEvent e) {
            TouchgraphEntityNode mouseOverN = (TouchgraphEntityNode) tgPanel.getMouseOverN();

            if (mouseOverN != null) {
                tgPanel.setToolTipText(mouseOverN.getLabel());
            } else {
                tgPanel.setToolTipText(null);
            }
        }

        public void mouseDragged(MouseEvent e) {
        }
    }

    class EntityNavigateMouseListener extends MouseAdapter {
        public void mousePressed(MouseEvent e) {
            Node mouseOverN = tgPanel.getMouseOverN();

            if (e.getModifiers() == MouseEvent.BUTTON1_MASK) {
                if (mouseOverN == null) {
                    hvDragUI.activate(e);
                } else {
                    dragNodeUI.activate(e);
                }
            }
        }

        public void mouseClicked(MouseEvent e) {
            Node mouseOverN = tgPanel.getMouseOverN();

            if (e.getModifiers() == MouseEvent.BUTTON1_MASK) {
                if (mouseOverN != null) {
                    if (e.getClickCount() == 2) {
                        Entity entity = ((TouchgraphEntityNode) mouseOverN).getEntity();
                        fireDisplayMessageEvent(entity);
                    } else {
                        tgPanel.setSelect(mouseOverN);

                        try {
                            tgPanel.setLocale(mouseOverN, 
                                              localityScroll.getLocalityRadius());
                        } catch (TGException ex) {
                            System.out.println("Error setting locale");
                            ex.printStackTrace();
                        }

                        //hvScrollToCenterUI.activate(e);                        
                    }
                }
            }
        }

        /**
         * Fires an EntityDisplayRequestEvent containing the given (email) Entity.
         */
        private void fireDisplayMessageEvent(final Entity message) {
            try {
                KernelProxy.getInstance()
                           .addEvent(new EntityDisplayRequestEvent(
                                             KernelProxy.getInstance()
                                                        .getEventGenerator(), 
                                             message));
            } catch (DataManagerException exception) {
                // FIXME: bogus exception
                Debug.writeLogMessage("Unable to fire entity display event: " + 
                                      exception);
                throw new RuntimeException(exception);
            }
        }

        public void mouseReleased(MouseEvent e) {
            if (e.isPopupTrigger()) {
                popupNode = tgPanel.getMouseOverN();
                popupEdge = tgPanel.getMouseOverE();

                if (popupNode != null) {
                    tgPanel.setMaintainMouseOver(true);
                    nodePopup.show(e.getComponent(), e.getX(), e.getY());
                } else if (popupEdge != null) {
                    tgPanel.setMaintainMouseOver(true);
                    edgePopup.show(e.getComponent(), e.getX(), e.getY());
                } else {
                    entityDisplayPanel.getPopup()
                                      .show(e.getComponent(), e.getX(), 
                                            e.getY());
                }
            }
        }
    }
}