// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.simpleton;

import java.awt.BorderLayout;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.WindowConstants;
import javax.swing.event.TreeExpansionEvent;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.event.TreeWillExpandListener;

//import javax.swing.event.TreeWillExpansionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeCellRenderer;
import javax.swing.tree.DefaultTreeModel;

import org.datamanager.constraint.*;
import org.datamanager.constraint.EventConstraint;
import org.datamanager.constraint.EventTypeIsConstraint;

import org.datamanager.event.AddEntityPoolEvent;
import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventHandler;
import org.datamanager.kernel.Pool;
import org.datamanager.kernel.Simpleton;

import org.datamanager.passiveentityvalue.NullEntityValue;
import org.datamanager.passiveentityvalue.StringEntityValue;

import org.datamanager.tools.kernelproxy.KernelProxy;


/**
 * Providesa a JTree view of the Entities in the pool and each Entity's value
 * and attributes.
 *
 * @author Xi Rao
 */
public class EntityViewerSimpleton extends Simpleton implements EventHandler {
    /** This Simpleton's toplevel frame. */
    private JFrame frame;

    /** The tree control with which we display the Entities. */
    private JTree tree;

    /** The label above the tree control in the frame. */
    private JLabel label;

    /** The button you press to close this window. */
    private JButton exitButton;

    /** The default pool. */
    private Pool pool;

    /** Tree model containing the Entities displayed in the tree. */
    private DefaultTreeModel defaultTreeModel;

    /** The root node in the tree. */
    private DefaultMutableTreeNode root;

    /**
     * Subscribes this Simpleton to all AddEntityPoolEvents, then builds the GUI.
     */
    public void process() {
        initialize();
        makeFrame();
    }

    /**
     * Subscribes this Simpleton to the pool to hear Events whenever any Entity is added.
     */
    private void initialize() {
        try {
            pool = Pool.getDefaultPool();

            EventConstraint eventConstraint = new EventTypeIsConstraint(
                                                      AddEntityPoolEvent.class);
            pool.subscribe(this, eventConstraint);
        } catch (Exception everything) {
            everything.printStackTrace();
        }
    }

    /**
     * Creates the GUI.
     */
    private void makeFrame() {
        frame = new JFrame("EntityViewerSimpleton");

        setupTree();


        //this is create some entity for self test
        createAndAttachEntity();

        exitButton = new JButton("ok");
        label = new JLabel();
        updateLabelText();
        frame.getContentPane().add(label, BorderLayout.NORTH);
        frame.getContentPane().add(exitButton, BorderLayout.SOUTH);
        frame.setSize(400, 600);
        frame.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
        frame.setVisible(true);
    }

    private void setupTree() {
        try {
            defaultTreeModel = new DefaultTreeModel(buildNodes());
            tree = new JTree(defaultTreeModel);

            DefaultTreeCellRenderer renderer = new DefaultTreeCellRenderer();
            tree.setCellRenderer(renderer);
            tree.setShowsRootHandles(true);


            //tree.addTreeSelectionListener(new EntitySelectListener());
            tree.addTreeWillExpandListener(new EntityExpandListener());

            JScrollPane s = new JScrollPane();
            s.getViewport().add(tree);
            frame.getContentPane().add(s, BorderLayout.CENTER);
        } catch (Exception everything) {
            everything.printStackTrace();
        }
    }

    private DefaultMutableTreeNode buildNodes() {
        root = new DefaultMutableTreeNode("entities in the pool");

        try {
            Entity[] entities = pool.search(EntityConstraint.NONE);

            // add build new treeNode and add it under root
            for (int i = 0; i < entities.length; i++) {
                root.add(buildEntityAttributes(entities[i]));
            }
        } catch (Exception everything) {
            everything.printStackTrace();
        }

        return root;
    }

    private DefaultMutableTreeNode buildEntityAttributes(Entity entity) {
        DefaultMutableTreeNode tempEntity = null;

        try {
            tempEntity = new DefaultMutableTreeNode(entity);

            Entity[] attributes = entity.getAttributes(EntityConstraint.NONE);

            for (int i = 0; i < attributes.length; i++) {
                tempEntity.add(new DefaultMutableTreeNode(attributes[i]));
            }
        } catch (Exception everything) {
            everything.printStackTrace();
        }

        return tempEntity;
    }

    /**
     * Updates the label with the current count of Entities.
     */
    private void updateLabelText() {
        label.setText("Entities in the pool :" + 
                      defaultTreeModel.getChildCount(defaultTreeModel.getRoot()));
    }

    public void handle(DataManagerEvent dataManagerEvent) {
        try {
            Entity entity = ((AddEntityPoolEvent) dataManagerEvent).getEntity();
            defaultTreeModel.insertNodeInto(buildEntityAttributes(entity), root, 
                                            root.getChildCount());
            defaultTreeModel.nodeChanged(root);
            updateLabelText();
        } catch (Exception everything) {
            everything.printStackTrace();
            throw new RuntimeException(everything);
        }
    }

    // for testing purpose to create entity for view...
    private void createEntity() {
        try {
            Entity entity = Entity.create("abracadabra");
            KernelProxy kernelProxy = KernelProxy.getInstance();
            kernelProxy.setEntityValue(entity, 
                                       new StringEntityValue("frizzuit"));
            kernelProxy.addEntity(entity);

            //FIXME: make sure cdent's KernelProxy attach works?

            /*
            Entity entity2 = Entity.create("xirao");
            KernelProxy kernelProxy2 = KernelProxy.getInstance();
            kernelProxy2.setEntityValue(entity, new StringEntityValue("frizzuit2"));
            kernelProxy.attachEntity(entity,entity2);
             */
        } catch (DataManagerException exception) {
            exception.printStackTrace();
        }
    }

    /**
     * Creates some test Entities to exercise this Simpleton.
     */
    private void createAndAttachEntity() {
        try {
            Entity entity = Entity.create("test Entity source");
            entity.setValue(new StringEntityValue("test Entity source"));

            Entity entity2 = Entity.create("test Entity attr2");
            entity2.setValue(new StringEntityValue("test Entity sattr2"));

            Entity entity3 = Entity.create("test Entity attr3");
            entity3.setValue(new StringEntityValue("test Entity sattr3"));

            Entity entity4 = Entity.create("test Entity attr4");
            entity4.setValue(new StringEntityValue("test Entity sattr4"));

            entity2.attach(entity4);
            entity2.attach(entity3);
            entity.attach(entity2);
            pool.add(entity);
        } catch (Exception everything) {
            everything.printStackTrace();
        }
    }

    //Now, This handler class is not use.
    class EntitySelectListener implements TreeSelectionListener {
        public void valueChanged(TreeSelectionEvent e) {
            //System.out.println(" select the tree node event");
            //createEntity();
        }
    }

    class EntityExpandListener implements TreeWillExpandListener {
        public void treeWillExpand(TreeExpansionEvent event) {
            DefaultMutableTreeNode tempNode = null;

            //find the last one on the tree node, this mean find the current node beside mouse click the tree
            //expand icon
            for (int i = 0; i < event.getPath().getPathCount(); i++) {
                tempNode = (DefaultMutableTreeNode) (event.getPath().getPath()[i]);
            }

            if (tempNode.getUserObject() instanceof Entity) {
                Entity tempEntity = (Entity) (tempNode.getUserObject());

                //travel each child node
                for (int i = 0; i < tempNode.getChildCount(); i++) {
                    DefaultMutableTreeNode child = (DefaultMutableTreeNode) tempNode.getChildAt(i);

                    // already added, not need to re-add
                    if (child.getChildCount() > 0) {
                        return;
                    } else {
                        Entity entity = (Entity) child.getUserObject();

                        try {
                            Entity[] attributes = entity.getAttributes(
                                                          EntityConstraint.NONE);

                            //travel each attribute
                            for (int j = 0; j < attributes.length; j++)
                                defaultTreeModel.insertNodeInto(
                                        new DefaultMutableTreeNode(
                                                attributes[j]), 
                                        (DefaultMutableTreeNode) child, j);
                        } catch (Exception everything) {
                            everything.printStackTrace();
                        }
                    }
                }
            }

            defaultTreeModel.nodeChanged(root);
        }

        public void treeWillCollapse(TreeExpansionEvent event) {
        }
    }
}

/*
 *
 * $Log: EntityViewerSimpleton.java,v $
 * Revision 1.10  2002/12/20 20:52:39  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.9  2002/11/17 08:46:54  alllee
 * Retrofitted the various Simpletons to comply with the new ContainsEntityEvent
 * refactoring and finished the initial stab at making EmailDisplaySimpleton
 * handle appropriate EntityDisplayRequestEvents.  Also playing with
 * Web*Simpletons (beyond making them fit with the new
 * EventContainsEntityConstraint style) to see if I can stop them from always
 * getting modified when ant codebase-style is run.
 *
 * Revision 1.8  2002/11/04 16:48:55  mafarrel
 * ran ant codebase-style...
 *
 * Revision 1.7  2002/11/04 01:14:32  mliggett
 * - Refactored slightly:  renamed a few methods; added and improved a few javadoc
 *   comments.
 * - The label at the top of the viewer now displays the total number of Entities
 *   in the Pool.  NOTE:  This is not necessarily equal to the total number of
 *   Entities in the system.
 *
 *
 */
