// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.simpleton;

import org.datamanager.constraint.EventTypeIsConstraint;

import org.datamanager.event.DataManagerEvent;
import org.datamanager.event.KernelShutdownRequestEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.EventHandler;
import org.datamanager.kernel.Pool;
import org.datamanager.kernel.Simpleton;

import org.datamanager.tools.Debug;


/**
 * KernelShutdownSimpleton handles KernelShutdownRequestEvents and invokes
 * System.exit(0). At this time the only think firing the KernelShutdown
 * RequestEvent is the ShutdownSimpleton.
 *
 * Created: Sun Nov  3 23:40:49 2002
 *
 * @author Allen Lee
 * @author Bob George
 * @version $Revision: 1.4 $
 * 
 */
public class KernelShutdownSimpleton extends Simpleton
    implements EventHandler {
    public void process() {
        attachToPool();
    }

    private void attachToPool() {
        try {
            Pool.getDefaultPool()
                .subscribe(this, 
                           new EventTypeIsConstraint(
                                   KernelShutdownRequestEvent.class));
        } catch (DataManagerException exception) {
            exception.printStackTrace();
            Debug.writeLogMessage(
                    "KernelShutdownSimpleton unable to subscribe to the Pool");
        }
    }

    public void handle(DataManagerEvent event) {
        if (event instanceof KernelShutdownRequestEvent) {
            System.err.println("System is shutting down.");
            System.exit(0);
        } else {
            System.err.println("Invalid shutdown event: " + event);
            Debug.writeLogMessage(
                    "KernelShutdownSimpleton received wrong event type: " + 
                    event);
        }
    }
} // KernelShutdownSimpleton
