// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.simpleton;

import java.util.Properties;

// FIXME: bad form
import javax.mail.*;
import javax.mail.internet.*;

import org.datamanager.constraint.EventConstraint;
import org.datamanager.constraint.EventTypeIsConstraint;

import org.datamanager.event.DataManagerEvent;
import org.datamanager.event.EmailParametersEnteredCollectorEvent;
import org.datamanager.event.EmailParametersRequestEvent;
import org.datamanager.event.SMTPSendRequestEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventHandler;
import org.datamanager.kernel.Pool;
import org.datamanager.kernel.Simpleton;

import org.datamanager.passiveentityvalue.EmailParametersEntityValue;

import org.datamanager.simpleton.EmailMessageEntityHelper;
import org.datamanager.simpleton.EmailParameters;

import org.datamanager.tools.Debug;
import org.datamanager.tools.kernelproxy.KernelProxy;


/**
 *
 * This class attempts to deliver a message
 * described by an Entity with an SMTPSendRequestEvent
 * over SMTP.
 */
public class SMTPSendSimpleton extends Simpleton implements EventHandler {
    /** Properties for sending mail. */
    private static final String SMTP_PROPERTY = "mail.smtp.host";
    private static final String SMTP_SERVER_DEFAULT = "mail-relay.indiana.edu";

    /** Vanity header for outgoing email messages. */
    private static final String VANITY_HEADER = "X-Mailer";
    private static final String VANITY_MAILER = "Helium http://helium.knownspace.org/";

    /** The user's email preferences. */
    private EmailParameters emailParameters = null;

    /**
     * Subscribes to the pool to hear the SMTPSendRequestEvent
     */
    public void process() {
        try {
            Pool pool = Pool.getDefaultPool();

            pool.subscribe(this, 
                           new EventTypeIsConstraint(SMTPSendRequestEvent.class));

            pool.subscribe(this, 
                           new EventTypeIsConstraint(
                                   EmailParametersEnteredCollectorEvent.class));
            pool.add(new EmailParametersRequestEvent(pool));
        } catch (DataManagerException exception) {
            // FIXME: usual bogus exception handling
            throw new RuntimeException(exception);
        }
    }

    /**
     * Handles and distributes the events to which this
     * Simpleton is subscribed.
    */
    public void handle(DataManagerEvent dataManagerEvent) {
        try {
            if (dataManagerEvent instanceof SMTPSendRequestEvent) {
                handleSend((SMTPSendRequestEvent) dataManagerEvent);
            } else if (dataManagerEvent instanceof EmailParametersEnteredCollectorEvent) {
                handleParameters(
                        (EmailParametersEnteredCollectorEvent) dataManagerEvent);
            }
        } catch (DataManagerException exception) {
            // FIXME: usual bogus exception handling
            throw new RuntimeException(exception);
        } catch (ClassCastException exception) {
            // FIXME: usual bogus exception handling
            throw new RuntimeException(exception);
        }
    }

    /**
     * Handles SMTPSendRequestEvent, retrieving the message
     * and sending it.
     */
    private void handleSend(SMTPSendRequestEvent smtpEvent)
                     throws DataManagerException {
        Entity message = smtpEvent.getEntity();
        sendMessage(message);
    }

    /**
     * Handles the EmailParametersEnteredCollectorEvent, 
     * acquiring the EmailParameter.
     */
    private void handleParameters(EmailParametersEnteredCollectorEvent parametersEvent)
                           throws DataManagerException {
        emailParameters = new EmailParameters(
                                  (EmailParametersEntityValue) parametersEvent.getEntity()
                                                                              .getValue());
    }

    /**
     * Sends the mail message associated with the
     * given message Entity over SMTP.
     *
     * FIXME: We need to do validation.
     */
    private void sendMessage(Entity messageEntity) {
        try {
            EmailMessageEntityHelper messageHelper = new EmailMessageEntityHelper(
                                                             messageEntity);

            Properties properties = System.getProperties();
            properties.put(SMTP_PROPERTY, getSMTPServer());

            Session session = Session.getInstance(properties, null);

            MimeMessage message = new MimeMessage(session);
            message.setFrom(new InternetAddress(messageHelper.getFromAddress()));


            // FIXME: this takes just one address but getToAddresses
            // returns a string of multiple addresses.
            message.addRecipient(Message.RecipientType.TO, 
                                 new InternetAddress(
                                         messageHelper.getToAddresses()));

            if (messageHelper.getCcAddresses().length() > 0) {
                message.addRecipient(Message.RecipientType.CC, 
                                     new InternetAddress(
                                             messageHelper.getCcAddresses()));
            }

            message.setSubject(messageHelper.getSubject());

            message.setText(messageHelper.getBody());

            String inReplyTo = messageHelper.getInReplyTo();

            if (inReplyTo.length() > 0) {
                message.setHeader(EmailMessageEntityHelper.MAIL_IN_REPLY_TO, 
                                  messageHelper.getInReplyTo());
            }

            message.setHeader(VANITY_HEADER, VANITY_MAILER);


            // FIXME: what are the ramifications of this. Are 
            // there failures? What happens? How do we requeue?
            Transport.send(message);
        } catch (Exception everything) {
            // FIXME: exceptionally bogus exception handling, there
            // are all sorts of exceptions being thrown in the above
            // block.
            throw new RuntimeException(everything);
        }
    }

    /**
     * Returns the SMTP server host to use for
     * sending mail. If the value is not set
     * a default is tried.
     */
    private String getSMTPServer() {
        if (emailParameters != null) {
            return emailParameters.getSMTPHost();
        }

        // FIXME: Is this wise. If we don't return
        // some value, what should happen?
        return SMTP_SERVER_DEFAULT;
    }
}

/*
 * $Log: SMTPSendSimpleton.java,v $
 * Revision 1.6  2002/12/20 20:52:39  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.5  2002/12/06 11:33:02  alllee
 * Now that EmailMessageEntityHelper throws a DataManagerException from both of
 * its constructors, we have to try/catch or re-throw in all these classes that
 * utilize EmailMessageEntityHelper.
 *
 * Revision 1.4  2002/11/23 06:05:51  cjdent
 *
 * Made adjustments to SMTPSendSimpleton so that:
 *
 * - It only puts in an In-Reply-To header if one is available
 *   on the source entity.
 *
 * - It adds an X-Mailer vanity header
 *
 * - Sets the CC if there is one
 *
 * Revision 1.3  2002/11/21 07:10:08  cjdent
 *
 * Adds support for adding an In-Reply-To header to the message that gets sent out.
 * Gets it from the In-Reply-To attribute on the message entity.
 *
 * Revision 1.2  2002/11/20 00:25:42  cjdent
 *
 *
 * EmailParametersEntityValue and EmailParameters
 *
 * Addition of SMTPHost field for the outgoing SMTP server
 * Updated the equals method in EmailParametersEntityValue to include the
 *   smtp and from address info. Was this right?
 *
 * Added an SMTP host to the EmailConfiguratorSimpleton
 *
 * SMTPSendSimpleton
 *  subscribes to the EmailParametersEnteredCollectorEvent and fires the
 *  EmailParametersRequestEvent to get SMTP host information.
 *
 *  FIXME: What happens if it is unable to get the info for some reason when
 *  it tries to make a delivery. I've set up a default, which is _not_ a good
 *  long term solution. This is integrated with the overall question of
 *  how to deal with SMTP errors.
 *
 * Rest is more bogus codebase-style
 *
 * Revision 1.1  2002/11/19 06:28:52  cjdent
 *
 * A simpleton that hears SMTPSendRequestEvents and sends the messages
 * out using SMTP.
 *
 * At the moment it is hardwired to use mail-relay.indiana.edu.
 *
 * It also has the most ridiculous exception catch (everything). See the FIXMEs
 * and a forthcoming, SMTP stuff message.
 *
 *
 */
