// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.simpleton;

import java.awt.BorderLayout;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.WindowConstants;

import org.datamanager.event.KernelShutdownRequestEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Pool;
import org.datamanager.kernel.Simpleton;

import org.datamanager.tools.Debug;
import org.datamanager.tools.kernelproxy.KernelProxy;


/** 
 * ShutdownSimpleton fires KernelShutdownRequestEvents when its big, red,
 * button is pressed.
 *
 * @author Allen lee
 * @author Bobert George
 * @version $Revision: 1.7 $
 */
public class ShutdownSimpleton extends Simpleton {
    private final static String BIG_RED_BUTTON_LOCATION = "shutdownButton.gif";

    public void process() {
        initializeGuiComponents();
    }

    private void initializeGuiComponents() {
        final JFrame frame = new JFrame("Shutdown Simpleton");
        final ImageIcon buttonIcon = getImageIcon(BIG_RED_BUTTON_LOCATION);
        final JButton shutdownButton = new JButton(buttonIcon);

        frame.getContentPane()
             .add(new JLabel("Shut it down."), BorderLayout.NORTH);
        frame.getContentPane().add(shutdownButton, BorderLayout.CENTER);
        shutdownButton.addMouseListener(new MouseAdapter() {
            public void mouseClicked(MouseEvent evt) {
                // addShutdownHook should have been installed already.
                try {
                    KernelProxy kernelProxy = KernelProxy.getInstance();
                    kernelProxy.addEvent(
                            new KernelShutdownRequestEvent(
                                    kernelProxy.getEventGenerator()));
                } catch (DataManagerException exception) {
                    exception.printStackTrace();


                    // FIXME:  Something real bad should happen if we
                    // can't shut down the machine.
                    Debug.writeLogMessage(
                            "DataManagerException generated while attempting to shut down.");
                }
            }
        });
        frame.pack();
        frame.show();
    }

    /**
     * Creates a FileInputStream that is the Startup Data File.
     */
    private ImageIcon getImageIcon(String file) {
        String iconFile = file;

        ImageIcon imageIcon = new ImageIcon(this.getClass().getClassLoader()
                                                .getResource(iconFile));

        if (imageIcon == null) {
            imageIcon = new ImageIcon(iconFile);
        }

        return imageIcon;
    }
}