// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.simpleton;

import com.touchgraph.graphlayout.Edge;
import com.touchgraph.graphlayout.Node;
import com.touchgraph.graphlayout.TGPanel;

import java.awt.Color;
import java.awt.Graphics;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;

import org.datamanager.simpleton.TouchgraphEntityNode;

import org.datamanager.tools.Toolbox;


/**
 * TouchgraphEntityEdge is a touchgraph Edge between
 * Entities. This is a modification of traditional
 * Touchgraph edges to be as simple as possible.
 */
public class TouchgraphEntityEdge extends com.touchgraph.graphlayout.Edge {
    /** Default color of edges. This is Yellow. */
    private static final Color DEFAULT_EDGE_COLOR = new Color(255, 255, 0);

    public TouchgraphEntityEdge(TouchgraphEntityNode node1, 
                                TouchgraphEntityNode node2, int length) {
        super((Node) node1, (Node) node2, length);
    }

    /**
     * Paints the Edge a simple line between two points
     * if the line is on screen.If the mouse is hovering over this
     * edge, a different color is used.
     */
    public void paint(Graphics g, TGPanel tgPanel) {
        Color c = (tgPanel.getMouseOverE() == this)
                  ? MOUSE_OVER_COLOR : DEFAULT_EDGE_COLOR;

        int x1 = (int) from.drawx;
        int y1 = (int) from.drawy;
        int x2 = (int) to.drawx;
        int y2 = (int) to.drawy;

        if (intersects(tgPanel.getSize())) {
            paintArrow(g, x1, y1, x2, y2, c);
        }
    }

    /**
     * Paints the edge on screen.
     */
    public static void paintArrow(Graphics g, int x1, int y1, int x2, int y2, 
                                  Color c) {
        g.setColor(c);
        g.drawLine(x1, y1, x2, y2);
    }
}