// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.tools;

import java.util.ArrayList;
import java.util.List;

import org.datamanager.kernel.Entity;


/**
 * A container class that is holds a list of Entities.
 * Entities may be added, and removed also.
 *
 * @author Gordon Murphy, gpmurphy@indiana.edu
 * @author Bryan Dawson, bdawson@indiana.edu
 */
public class EntityList {
    /** The list of Entities. */
    private List entities;

    /**
     * Create a new EntityList with the default length.
     */
    public EntityList() {
        entities = new ArrayList();
    }

    /**
     * Create a new EntityList containing the specified 
     * entity array. 
     */
    public EntityList(Entity[] list) {
        this();

        Entity entity;

        for (int i = 0; i < list.length; i++) {
            entity = list[i];
            add(entity);
        }
    }

    /**
     * Retrieves the entity at the specified index.
     * @param index the index to retrieve the entity from
     * @return the entity at index
     */
    public Entity get(int index) {
        return (Entity) entities.get(index);
    }

    /**
     * The number of entities in the list.
     * @return the number of entities in the list
     */
    public int size() {
        return entities.size();
    }

    /**
     * Returns true if the list contains the specified entity.
     * @return true or false
     */
    public boolean contains(Entity entity) {
        return entities.contains(entity);
    }

    /**
     * Inserts a entity at the specified index.
     * @param entity the entity to add
     * @param index the index to insert the entity at
     */
    public void add(int index, Entity entity) {
        entities.add(index, entity);
    }

    /**
     * Adds the specified entity to the list.
     * @param entity the entity to add
     */
    public void add(Entity entity) {
        entities.add(entity);
    }

    /**
     * Append the specified list to the list.
     * @param entities the EntityList to append to the end of this list
     */
    public void addEntities(EntityList entities) {
        int numEntities = entities.size();

        for (int i = 0; i <= (numEntities - 1); i++) {
            add(entities.get(i));
        }
    }

    /**
     * Removes the entity at the specified index and returns it.
     * @param index the index to remove the entity at.
     * @return the entity removed
     */
    public Entity remove(int index) {
        return (Entity) entities.remove(index);
    }

    /**
     * Removes the specified entity from the list.
     * @param entity the entity to remove
     */
    public void remove(Entity entity) {
        entities.remove(entity);
    }

    /**
     * Removes the specified list from this list.
     * @param entities the EntityList to remove from this list
     */
    public void removeEntities(EntityList entities) {
        int numEntities = entities.size();

        for (int i = 0; i <= (numEntities - 1); i++) {
            remove(entities.get(i));
        }
    }

    /**
     * Converts the contents to a string representation
     * @return a string representation of the contents
     */
    public String toString() {
        return entities.toString();
    }
}

/*
 *
 * $Log: EntityList.java,v $
 * Revision 1.3  2002/12/20 20:52:45  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.2  2002/11/10 07:46:00  mliggett
 * Fixed bogus javadoc tag.
 *
 * Revision 1.1  2002/10/29 05:35:33  cjdent
 *
 * Simpleton:
 *
 * 1) codebase-style cleanups
 * 2) WebAndNewsSearchSimpleton uses KernelProxy thus has to catch the
 *    DataManagerException that are now being thrown out of the KernelProxy
 *    (as described below)
 *
 * KernelProxy:
 *
 * 1) Code cleanup (still needs more)
 *    a) FIXME: in the handle() message. This may not be needed in our current
 *       implementation.
 *    b) NOT free of style crime
 * 2) Made everything that just catches a DataManagerException and then does
 *    nothing with it but print a stack trace not catch this exception.
 *    This is so we actually do something about them. Code that uses
 *    KernelProxy will need to catch these exceptions.
 * 3) Where necessary changed InterfaceEntityList to EntityList.
 * 4) Added Log message footers.
 *
 * EntityList:
 *
 * 1) Modified InterfaceEntityList to provide a more generic way of storing a
 *    a list of Entities. This is used in SearchWorker.
 * 2) Changed list queries like elementAt to indexOf
 * 3) Removed support for clusters.
 *
 *
 */
