// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.tools;

import org.datamanager.constraint.EventConstraint;

import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.EventHandler;
import org.datamanager.kernel.Pool;
import org.datamanager.kernel.Simpleton;


/**
 * Used to log all Events that pass through the KnownSpace kernel.  Handy for
 * developers as a state-examination or tracing tool.
 *
 * @author Matt Liggett
 */
public class EventLoggerSimpleton extends Simpleton implements EventHandler {
    /**
     * Starts this Simpleton and subscribes it to all events.
     */
    public void process() {
        try {
            Pool.getDefaultPool().subscribe(this, EventConstraint.NONE);
            Thread.currentThread().join(0); // sleep forever
        } catch (DataManagerException exception) {
            exception.printStackTrace();
        } catch (InterruptedException exception) {
            exception.printStackTrace();
        }
    }

    public void handle(DataManagerEvent dataManagerEvent) {
        Debug.writeLogMessage("EventLoggerSimpleton: Event: " + 
                              dataManagerEvent);
    }
}

/*
 * $Log: EventLoggerSimpleton.java,v $
 * Revision 1.3  2002/12/20 20:52:45  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.2  2002/10/28 15:52:01  mafarrel
 * Reformatted with 'ant codebase-style'
 *
 * Revision 1.1  2002/10/28 02:41:14  mliggett
 * Used to log all Events that pass through the KnownSpace kernel.  Handy for
 * developers as a state-examination or tracing tool.
 *
 */
