// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.tools;

import java.util.LinkedList;

import org.datamanager.kernel.Simpleton.Information;

import org.w3c.dom.Node;


/**
 * Parses the knownspace_config.xml file to gather the information
 * necessary for creating a Simpleton.Information object.
 */
public class InformationParser {
    public static Information parseInformation(Node informationNode) {
        String className = null;
        String name = null;
        String shortDescription = null;
        String longDescription = null;
        String version = null;
        String[] authors = null;
        boolean isUserInterface = false;
        boolean runOnStartup = false;
        String classLocation = null;

        Node child = informationNode.getFirstChild();

        if (informationNode.getNodeName().equalsIgnoreCase("UserInterface")) {
            isUserInterface = true;
        }

        while (child != null) {
            if (child.getNodeType() == Node.ELEMENT_NODE) {
                if (child.getNodeName().equalsIgnoreCase("Class")) {
                    className = parseInformationClass(child);
                } else if (child.getNodeName().equalsIgnoreCase("Name")) {
                    name = parseInformationName(child);
                } else if (child.getNodeName()
                                .equalsIgnoreCase("ShortDescription")) {
                    shortDescription = parseInformationShortDescription(child);
                } else if (child.getNodeName()
                                .equalsIgnoreCase("LongDescription")) {
                    longDescription = parseInformationLongDescription(child);
                } else if (child.getNodeName().equalsIgnoreCase("Version")) {
                    version = parseInformationVersion(child);
                } else if (child.getNodeName().equalsIgnoreCase("AuthorList")) {
                    authors = parseInformationAuthorList(child);
                } else if (child.getNodeName().equalsIgnoreCase("RunOnStartup")) {
                    runOnStartup = true;
                } else if (child.getNodeName()
                                .equalsIgnoreCase("ClassLocation")) {
                    classLocation = parseInformationClassLocation(child);
                } else {
                    // Error: Known tag.
                }
            }

            child = child.getNextSibling();
        }

        return new Information(className, name, shortDescription, 
                               longDescription, version, authors, 
                               isUserInterface, runOnStartup, classLocation);
    }

    protected static String parseInformationClass(Node node) {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
    }

    protected static String parseInformationName(Node node) {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
    }

    protected static String parseInformationShortDescription(Node node) {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
    }

    protected static String parseInformationLongDescription(Node node) {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
    }

    protected static String parseInformationVersion(Node node) {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
    }

    protected static String[] parseInformationAuthorList(Node node) {
        LinkedList authors = new LinkedList();
        Node child = node.getFirstChild();

        while (child != null) {
            if (child.getNodeType() == Node.ELEMENT_NODE) {
                if (child.getNodeName().equals("Author")) {
                    authors.add(parseInformationAuthorListAuthor(child));
                } else {
                    // Error: Known tag.
                }
            }

            child = child.getNextSibling();
        }

        return (String[]) authors.toArray(new String[0]);
    }

    protected static String parseInformationAuthorListAuthor(Node node) {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
    }

    protected static String parseInformationClassLocation(Node node) {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
    }
}