// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.tools;

import java.awt.*;
import java.awt.event.*;

import java.util.*;

import javax.swing.*;

import org.datamanager.constraint.*;

import org.datamanager.event.*;

import org.datamanager.exception.*;

import org.datamanager.kernel.*;


/**
 * A JPanel containing textual information about the
 * Entities in the Pool. Used by PoolViewer.
 *
 * @see org.datamanager.tools.PoolViewer
 */
public class ViewPool extends JPanel implements ActionListener {
    private JButton printEntities;
    private JButton clearTextArea;
    private JTextArea textArea;
    private JScrollPane scrollPane;

    public ViewPool() {
        setLayout(new BorderLayout());
        printEntities = new JButton("view entities");
        clearTextArea = new JButton("clear");

        JPanel buttonPanel = new JPanel();
        buttonPanel.add(printEntities);
        buttonPanel.add(clearTextArea);
        add(buttonPanel, BorderLayout.NORTH);
        textArea = new JTextArea();
        scrollPane = new JScrollPane(textArea);
        add(scrollPane, BorderLayout.CENTER);
        printEntities.addActionListener(this);
        clearTextArea.addActionListener(this);
    }

    public void viewEntities() {
        try {
            Pool pool = Pool.getDefaultPool();
            Entity[] entities = pool.search(EntityConstraint.NONE);
            StringBuffer entityStrings = new StringBuffer();

            for (int i = 0; i <= (entities.length - 1); i++) {
                entityStrings.append("" + entities[i].getName() + " " + 
                                     entities[i].getValue() + "\n");

                if ((i % 400) == 0) {
                    repaint();
                }
            }

            textArea.append("" + entityStrings);
        } catch (DataManagerException exception) {
        }
    }

    public void clearEntities() {
        textArea.setText("");
    }

    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == printEntities) {
            SwingUtilities.invokeLater(new Runnable() {
                public void run() {
                    viewEntities();
                }
            });
        } else if (e.getSource() == clearTextArea) {
            clearEntities();
        }
    }

    public static void main(String[] arguments) {
        JFrame frame = new JFrame();
        frame.getContentPane().add(new ViewPool());
        frame.setSize(300, 300);
        frame.show();
    }
}