// For licensing, see: http://helium.knownspace.org/license.html
//////////////////////////////////////////////////////////////
package org.datamanager.tools.kernelproxy;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EntityValue;
import org.datamanager.kernel.Pool;

import org.datamanager.passiveentityvalue.BooleanEntityValue;


////////////////////////////////////////////////////////////////////////////////

/**
 * Creates a new entity with another entity attached to it marking it 
 * as ignored to the interface.
 * A call to get() will retrieve the attribute as an Object.
 * <strong>Note: This thread will only work when run within the kernel on an 
 * approved thread.</strong>
 */
public class CreateAttributeWorker extends InterfaceWorker {
    /** The name of the entity created. */
    private String name;

    /**
     * Creates a new worker containing an entity.
     * @param name the name of the entity.
     */
    public CreateAttributeWorker(String name) {
        this.name = name;
    }

    /**
     * Creates an Entity that is to be ignored by the interface.
     * FIXME: What's an IGNORE_ENTITY?
     */
    protected Object construct() throws DataManagerException {
        Entity entity = null;

        entity = Entity.create(name);

        Entity attribute = Entity.create(KernelProxy.IGNORED_ENTITY);
        attribute.setValue(new BooleanEntityValue(true));
        entity.attach(attribute);

        return entity;
    }
}

/*
 *
 * $Log
 *
 */
