// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.tools.kernelproxy;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.Pool;


/**
 * Creates a new entity and adds it to the pool.
 * A call to get() will retrieve the entity as an Object.
 * <strong>Note: This thread will only work when run within the kernel on an 
 * approved thread.</strong>
 */
public class CreateEntityWorker extends InterfaceWorker {
    /** The name of the Entity being created. */
    private String name;

    /**
    * Creates a worker that makes a new entity and adds it to the pool.
    * @param the name of the new entity
    */
    public CreateEntityWorker(String name) {
        this.name = name;
    }

    /** 
     * Creates an Entity.
     *
     * @return The Entity created.
     */
    protected Object construct() throws DataManagerException {
        Entity entity = null;

        entity = Entity.create(name);
        Pool.getDefaultPool().add(entity);

        return entity;
    }
}

/*
 *
 * $Log
 *
 */
