// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.tools.kernelproxy;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.Pool;


/**
 * Detaches an entity as an attribute to another entity.
 * <strong>Note: This thread will only work when run within the kernel on an 
 * approved thread.</strong>
 */
public class DetachEntityWorker extends InterfaceWorker {
    /** The Entity from which the attribute is being detached. */
    private Entity base;

    /** The Entity which is being detached. */
    private Entity attribute;

    /**
    * Detaches attribute as an attribute from base.
    * @param base the entity the attribute will be detached from
    * @param attribute the entity that will be detached
    */
    public DetachEntityWorker(Entity base, Entity attribute) {
        this.base = base;
        this.attribute = attribute;
    }

    /**
     * Detaches attribute from base.
     */
    protected Object construct() throws DataManagerException {
        base.detach(attribute);

        return null;
    }
}

/*
 *
 * $Log
 *
 */
