// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.tools.kernelproxy;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EntityValue;
import org.datamanager.kernel.Pool;

import org.datamanager.passiveentityvalue.NullEntityValue;


/**
 * Retrieves the value of an entity.
 * A call to get() will retrieve the EntityValue as an Object.
 * <strong>Note: This thread will only work when run within the kernel on an 
 * approved thread.</strong>
 */
public class GetEntityValueWorker extends InterfaceWorker {
    /** The Entity for which the EntityValue is desired. */
    private Entity entity;

    /**
    * Creates a worker to get the value of an entity.
    * @param entity the entity to retrieve the value of
    */
    public GetEntityValueWorker(Entity entity) {
        this.entity = entity;
    }

    /**
     * Gets the EntityValue of an entity.
     *
     * @return entity's EntityValue.
     */
    protected Object construct() throws DataManagerException {
        EntityValue value = null;

        value = entity.getValue();

        if (value == null) {
            value = NullEntityValue.getInstance();
        }

        return value;
    }
}

/*
 *
 * $Log
 *
 */
