// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.tools.kernelproxy;

import org.datamanager.constraint.EventConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventHandler;
import org.datamanager.kernel.Pool;


/**
 * Subscribes a handler to all events matching the given constraint.  
 * A call to get() will retrieve the value of the operation
 * <strong>Note: This thread will only work when run within the kernel on an 
 * approved thread.</strong>
 */
public class SubscriptionWorker extends InterfaceWorker {
    /** The EventConstraint subscribed. */
    private EventConstraint constraint;

    /** The EventHandler being subscribed. */
    private EventHandler handler;

    /**
    * Creates a worker to subscribe the handler to events.
    * @param constraint the constraint describing an event.
    * @param handler the EventHandler to be subscribed
    */
    public SubscriptionWorker(EventConstraint constraint, EventHandler handler) {
        this.constraint = constraint;
        this.handler = handler;
    }

    /**
     * Subscribes a handler to the Pool with a constraint.
     */
    protected Object construct() throws DataManagerException {
        Pool.getDefaultPool().subscribe(handler, constraint);

        return null;
    }
}

/*
 *
 * $Log
 *
 */
