// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.constraint;

import java.util.Date;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.constraint.DateValueRangeConstraint;
import org.datamanager.constraint.EntityConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;

import org.datamanager.passiveentityvalue.DateEntityValue;

import org.datamanager.test.ConstraintApplier;


public class DateValueRangeConstraintTester extends TestCase {
    ConstraintApplier constraintApplier;
    Entity dateEntity1;
    Date minDate;
    Date maxDate;

    public DateValueRangeConstraintTester(String string) {
        super(string);
    }

    public static Test suite() {
        return new TestSuite(DateValueRangeConstraintTester.class);
    }

    public void setUp() {
        try {
            long time = System.currentTimeMillis();
            dateEntity1 = Entity.create("dateEntity1");
            dateEntity1.setValue(new DateEntityValue(new Date(time)));
            maxDate = new Date(time + (1000 * 60 * 60 * 12));
            minDate = new Date(time - (1000 * 60 * 60 * 12));
        } catch (DataManagerException exception) {
            throw new RuntimeException(exception);
        }

        constraintApplier = new ConstraintApplier();
    }

    /**
     * Tests that the constraint does not match Entities it should not.
     */
    public void testNoMatch() throws InterruptedException {
        assertFalse(constraintApplier.applyConstraint(
                            new DateValueRangeConstraint(maxDate, minDate), 
                            dateEntity1));
    }

    /**
     * Tests that the constraint matches when it's supposed to.
     */
    public void testMatch() throws InterruptedException {
        assertTrue(constraintApplier.applyConstraint(
                           new DateValueRangeConstraint(minDate, maxDate), 
                           dateEntity1));
    }
}

/*
 * $Log: DateValueRangeConstraintTester.java,v $
 * Revision 1.2  2002/12/20 20:52:49  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.1  2002/11/18 00:45:29  cjdent
 *
 * A constraint for matching an entity that has a DateEntityValue between
 * two Dates that are provided to the constraint. This is to enable date
 * based metadata searches. See a forthcoming email message for various issues
 * associated with this.
 *
 * Also a test class for it.
 *
 *
 */
