// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.constraint;

import java.util.regex.Pattern;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.constraint.EntityConstraint;
import org.datamanager.constraint.StringValueMatchesConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.Simpleton;

import org.datamanager.passiveentityvalue.StringEntityValue;

import org.datamanager.test.ConstraintApplier;


public class StringValueMatchesConstraintTester extends TestCase {
    ConstraintApplier constraintApplier;
    Entity matchEntity;

    public StringValueMatchesConstraintTester(String string) {
        super(string);
    }

    public static Test suite() {
        return new TestSuite(StringValueMatchesConstraintTester.class);
    }

    public void setUp() {
        try {
            matchEntity = Entity.create("testMatch");
            matchEntity.setValue(
                    new StringEntityValue(
                            "constraint unit test / match my attribute value / give boolean true"));
        } catch (DataManagerException exception) {
            throw new RuntimeException(exception);
        }

        constraintApplier = new ConstraintApplier();
    }

    /**
     * Tests that the constraint does not match Entities it should not.
     */
    public void testNoMatch() throws InterruptedException {
        assertFalse(constraintApplier.applyConstraint(
                            new StringValueMatchesConstraint("a.ribute"), 
                            matchEntity));
    }

    /**
     * Tests that the constraint matches when it's supposed to.
     */
    public void testMatch() throws InterruptedException {
        assertTrue(constraintApplier.applyConstraint(
                           new StringValueMatchesConstraint("a.tribute"), 
                           matchEntity));
    }
}

/*
 * $Log: StringValueMatchesConstraintTester.java,v $
 * Revision 1.2  2002/12/20 20:52:49  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.1  2002/11/16 19:51:49  mliggett
 * Adding new constraint which does pattern matching using java.util.regex.*,
 * and also a couple basic unit tests.
 *
 * This is in preparation for smarter Subject: searching.
 *
 *
 */
