// For licensing, see: http://helium.knownspace.org/license.html
// This has to go in kernel so we can create DataManagerWorkers.  Sigh.
package org.datamanager.kernel;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.constraint.AndEntityConstraint;
import org.datamanager.constraint.AttributeNameContainsConstraint;
import org.datamanager.constraint.EntityConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.DataManagerWorker;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.Simpleton;

import org.datamanager.passiveentityvalue.StringEntityValue;

import org.datamanager.test.ConstraintApplier;


public class AndEntityConstraintTester extends TestCase {
    ConstraintApplier constraintApplier;
    Entity matchEntity;

    public AndEntityConstraintTester(String string) {
        super(string);
    }

    public static Test suite() {
        return new TestSuite(AndEntityConstraintTester.class);
    }

    public void setUp() {
        try {
            matchEntity = Entity.create("testMatch");

            Entity attribute1Entity = Entity.create("haiku");
            attribute1Entity.setValue(
                    new StringEntityValue(
                            "constraint unit test / match my attribute value / give boolean true"));
            matchEntity.attach(attribute1Entity);

            Entity attribute2Entity = Entity.create("free-verse");
            attribute2Entity.setValue(
                    new StringEntityValue(
                            "once, in simple pleasure, we late night rode"));
            matchEntity.attach(attribute2Entity);
        } catch (DataManagerException exception) {
            throw new RuntimeException(exception);
        }

        constraintApplier = new ConstraintApplier();
    }

    /**
     * Tests that the constraint does not match Entities it should not.
     */
    public void testNoMatch() throws InterruptedException {
        assertFalse(constraintApplier.applyConstraint(
                            new AndEntityConstraint(
                                    new AttributeNameContainsConstraint("haiku", 
                                                                        "baked chicken"), 
                                    new AttributeNameContainsConstraint(
                                            "free-verse", "simple pleasure")), 
                            matchEntity));
    }

    /**
     * Tests that the constraint matches when it's supposed to.
     */
    public void testMatch() throws InterruptedException {
        assertTrue(constraintApplier.applyConstraint(
                           new AndEntityConstraint(
                                   new AttributeNameContainsConstraint("haiku", 
                                                                       "unit test"), 
                                   new AttributeNameContainsConstraint(
                                           "free-verse", "simple pleasure")), 
                           matchEntity));
    }
}

/*
 * $Log: AndEntityConstraintTester.java,v $
 * Revision 1.5  2002/12/20 20:52:50  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.4  2002/11/13 08:26:22  cjdent
 *
 * Codebase style.
 *
 * We need to decide if it is in or out. Most people don't seem to be
 * running codebase style before they commit.
 *
 * Revision 1.3  2002/11/07 04:51:44  mliggett
 * Modified tests to use ConstraintApplier.
 *
 * Revision 1.2  2002/11/07 04:00:58  mliggett
 * 1. Removed the DataManagerWorker per MattF's suggestion.  That means
 *    this tester could now be moved out of the kernel package.  But more
 *    importantly, it's a lot simpler.
 * 2. Stopped catching exceptions where possible.  Our testFoo() methods
 *    can just declare 'throws', which simplifies the code further.
 *
 * Revision 1.1  2002/10/30 08:17:32  cjdent
 *
 * Copies with modification of the AttributeNameContainsConstraintTester
 * for testing the AndEntityConstraint and OrEntityConstraint type of constraints.
 *
 * Revision 1.3  2002/10/29 14:47:23  mliggett
 * Unbreaking unit test.
 *
 * Revision 1.2  2002/10/29 14:41:48  mliggett
 * Breaking a unit test on purpose to make sure CruiseControl is really running them.
 *
 * Revision 1.1  2002/10/29 06:35:07  mafarrel
 * Moved to the constraint package from the kernel package.
 *
 * Revision 1.1  2002/10/29 04:00:44  mliggett
 * Modified AttributeNameContainsConstraint to do what its name implies.
 * Wrote a test for it.
 *
 */
