// For licensing, see: http://helium.knownspace.org/license.html
// This has to go in kernel so we can create DataManagerWorkers.  Sigh.
package org.datamanager.kernel;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.constraint.AttributeNameContainsConstraint;
import org.datamanager.constraint.EntityConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.DataManagerWorker;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.Simpleton;

import org.datamanager.passiveentityvalue.StringEntityValue;

import org.datamanager.test.ConstraintApplier;


public class AttributeNameContainsConstraintTester extends TestCase {
    ConstraintApplier constraintApplier;
    Entity matchEntity;

    public AttributeNameContainsConstraintTester(String string) {
        super(string);
    }

    public static Test suite() {
        return new TestSuite(AttributeNameContainsConstraintTester.class);
    }

    public void setUp() {
        try {
            matchEntity = Entity.create("testMatch");

            Entity attributeEntity = Entity.create("haiku");
            attributeEntity.setValue(
                    new StringEntityValue(
                            "constraint unit test / match my attribute value / give boolean true"));
            matchEntity.attach(attributeEntity);
        } catch (DataManagerException exception) {
            throw new RuntimeException(exception);
        }

        constraintApplier = new ConstraintApplier();
    }

    /**
     * Tests that the constraint does not match Entities it should not.
     */
    public void testNoMatch() throws InterruptedException {
        assertFalse(constraintApplier.applyConstraint(
                            new AttributeNameContainsConstraint("haiku", 
                                                                "baked chicken"), 
                            matchEntity));
    }

    /**
     * Tests that the constraint matches when it's supposed to.
     */
    public void testMatch() throws InterruptedException {
        assertTrue(constraintApplier.applyConstraint(
                           new AttributeNameContainsConstraint("haiku", 
                                                               "unit test"), 
                           matchEntity));
    }
}

/*
 * $Log: AttributeNameContainsConstraintTester.java,v $
 * Revision 1.6  2002/12/20 20:52:50  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.5  2002/11/13 08:26:22  cjdent
 *
 * Codebase style.
 *
 * We need to decide if it is in or out. Most people don't seem to be
 * running codebase style before they commit.
 *
 * Revision 1.4  2002/11/07 04:51:44  mliggett
 * Modified tests to use ConstraintApplier.
 *
 * Revision 1.3  2002/10/29 14:47:23  mliggett
 * Unbreaking unit test.
 *
 * Revision 1.2  2002/10/29 14:41:48  mliggett
 * Breaking a unit test on purpose to make sure CruiseControl is really running them.
 *
 * Revision 1.1  2002/10/29 06:35:07  mafarrel
 * Moved to the constraint package from the kernel package.
 *
 * Revision 1.1  2002/10/29 04:00:44  mliggett
 * Modified AttributeNameContainsConstraint to do what its name implies.
 * Wrote a test for it.
 *
 */
