// For licensing, see: http://helium.knownspace.org/license.html
// 2002-10-13 mml
// Created so that we can examine persistence.
///////////////////////////////////////////////////////////////////////////////
package org.datamanager.kernel;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import java.lang.InterruptedException;
import java.lang.Thread;

import java.util.Vector;

import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JScrollPane;
import javax.swing.WindowConstants;

import org.datamanager.constraint.EntityConstraint;
import org.datamanager.constraint.EventConstraint;
import org.datamanager.constraint.EventTypeIsConstraint;

import org.datamanager.event.AddEntityPoolEvent;
import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.EventHandler;
import org.datamanager.kernel.Simpleton;

import org.datamanager.passiveentityvalue.StringEntityValue;

import org.datamanager.tools.kernelproxy.KernelProxy;


/**
 * A Simpleton to examine persistence.
 *
 * @author Matt Liggett
 */
public class EntityMakerSimpleton extends Simpleton implements EventHandler {
    /** A model for the list of all Entities we know about. */
    private DefaultListModel entityModel = new DefaultListModel();

    /** A display list of all Entities we know about. */
    private JList entityList;

    /** A scrollpane for the entityList. */
    private JScrollPane entityScrollPane;

    /** A button to make a new Entity. */
    private JButton makeEntityButton;

    /** This Simpleton's toplevel graphical element. */
    private JFrame frame;

    /**
     * Builds and displays the GUI.
     */
    public void process() {
        makeFrame();
        frame.setVisible(true);

        try {
            Pool pool = Pool.getDefaultPool();
            EventConstraint eventConstraint = new EventTypeIsConstraint(
                                                      AddEntityPoolEvent.class);
            pool.subscribe(this, eventConstraint);

            // suck in the list of existing entities
            Entity[] entityArray = Pool.getDefaultPool()
                                       .search(EntityConstraint.NONE);

            for (int i = 0; i < entityArray.length; i++) {
                addToListModel(entityArray[i]);
            }
        } catch (DataManagerException exception) {
            exception.printStackTrace();
        }
    }

    /**
     * Adds an Entity to the JList ListModel
     */
    private synchronized void addToListModel(Entity entity) {
        if (!entityModel.contains(entity)) {
            entityModel.addElement(entity);
        }
    }

    /**
     * Reacts to the AddEntityPoolEvent, adding the Entity to the
     * ListModel for the JList.
     */
    public void handle(DataManagerEvent dataManagerEvent) {
        AddEntityPoolEvent event = (AddEntityPoolEvent) dataManagerEvent;
        addToListModel(event.getEntity());
    }

    /**
     * Adds a meaningless Entity to the pool.
     */
    private void createEntity() {
        try {
            Entity entity = Entity.create("abracadabra");
            KernelProxy kernelProxy = KernelProxy.getInstance();
            kernelProxy.setEntityValue(entity, 
                                       new StringEntityValue("frizzuit"));
            kernelProxy.addEntity(entity);
        } catch (DataManagerException exception) {
            exception.printStackTrace();
        }
    }

    /**
     * Creates the JFrame and other components that go in it; configures
     * layout.
     */
    private void makeFrame() {
        frame = new JFrame(getInformation().getName());
        frame.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
        frame.setSize(150, 600);

        entityList = new JList(entityModel);
        entityScrollPane = new JScrollPane(entityList);
        frame.getContentPane().add(entityScrollPane, BorderLayout.CENTER);

        makeEntityButton = new JButton("Make Entity");
        makeEntityButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent event) {
                createEntity();
            }
        });

        frame.getContentPane().add(makeEntityButton, BorderLayout.SOUTH);

        frame.getContentPane().add(new JLabel("Entities"), BorderLayout.NORTH);
    }
}

/*
 *
 * $Log: EntityMakerSimpleton.java,v $
 * Revision 1.8  2002/12/20 20:52:50  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.7  2002/11/17 08:54:40  alllee
 * Modified test to use getEntity() instead of getAddedEntity() since an
 * AddEntityPoolEvent implements the ContainsEntityEvent interface now.
 *
 * Revision 1.6  2002/10/29 01:19:41  mliggett
 * Fixed the doc comment on process()
 *
 * Revision 1.5  2002/10/28 05:30:30  cjdent
 *
 * Updated, as a test of KernelProxy, to:
 *
 * 1) Have a JScrollPane with a JList that updates with a DefaultListModel
 *    - Sometimes the JList does not update. This appears to be a JList problem.
 * 2) Use KernelProxy to
 *    - add Entities
 *    - set Entity values
 * 3) Updates to ListModel are done in a synchronized fashion to try to
 *    avoid repeats in the list. For other applications probably wise to
 *    extend AbstractListModel to use a Set.
 *
 * Revision 1.4  2002/10/25 05:19:00  cjdent
 *
 *
 * Incomplete work to make EntityMakerSimpleton hear
 * AddEntityPoolEventS and update itself accordingly (rather than
 * constantly search the pool).
 *
 * Not yet working.
 *
 *
 */
