// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.kernel;

import java.util.List;

import junit.framework.Assert;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.constraint.EventConstraint;

import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;


public class EventHandlerThreadTester extends TestCase {
    private boolean eventWasHandled;
    private EventHandlerThread eventHandlerThread;
    private EventHandler eventHandler;
    private DataManagerEvent dataManagerEvent;

    public EventHandlerThreadTester(String s) {
        super(s);
    }

    public static Test suite() {
        TestSuite suite = new TestSuite("EventHandlerThreadTester");
        suite.addTest(new EventHandlerThreadTester("testProcess"));

        return suite;
    }

    protected void setUp() {
        eventHandler = new EventHandler() {
            public void handle(DataManagerEvent event) {
                eventWasHandled = true;
            }
        };


        dataManagerEvent = new DataManagerEvent() {
            public EventGenerator getSource() {
                return null;
            }

            public long getTime() {
                return System.currentTimeMillis();
            }

            public String toString() {
                return "DataManagerEvent instance";
            }
        };


        eventHandlerThread = new EventHandlerThread(eventHandler, 
                                                    dataManagerEvent);
    }

    protected void tearDown() {
        eventHandlerThread = null;
        eventHandler = null;
        dataManagerEvent = null;
    }

    public void testProcess() {
        assertTrue("The event should not have been handled (false).", 
                   !getEventWasHandled());
        eventHandlerThread.process();
        assertTrue("The event should have been handled (true).", 
                   getEventWasHandled());
    }

    private boolean getEventWasHandled() {
        return eventWasHandled;
    }
}