// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.kernel;

import junit.framework.*;

import org.datamanager.exception.DataManagerException;


public class KernelMemoryTester extends TestCase {
    protected IdentifierManager identifierManager = IdentifierManager.getInstance();

    public KernelMemoryTester(String s) {
        super(s);
    }

    protected void setUp() {
    }

    public static Test suite() {
        return new TestSuite(KernelMemoryTester.class);
    }

    protected void tearDown() {
    }

    public void testMe() {
    }

    public void testRemoveFromMemory() throws DataManagerException {
        KernelMemory kernelmemory = new KernelMemory();
        VerySimpleEntity entity = new VerySimpleEntity("name");
        Identifier identifier = identifierManager.getIdentifier();
        EntityProxy entityProxy = new EntityProxy(identifier, 
                                                  EntityManager.getInstance());

        VerySimpleEntity entity2 = new VerySimpleEntity("name2");
        Identifier identifier2 = identifierManager.getIdentifier();
        EntityProxy entityProxy2 = new EntityProxy(identifier2, 
                                                   EntityManager.getInstance());

        try {
            kernelmemory.loadIntoMemory(identifier, entity, entityProxy);
            kernelmemory.loadIntoMemory(identifier2, entity2, entityProxy2);
        } catch (Exception e) {
            System.err.println("Exception thrown:  " + e);
        }

        VerySimpleEntity removeEntity = (VerySimpleEntity) kernelmemory.removeFromMemory(
                                                identifier);
        this.assertEquals(removeEntity, entity);

        this.assertNull(kernelmemory.findEntity(identifier));
    }

    public void testLoadIntoMemory() throws DataManagerException {
        KernelMemory kernelmemory = new KernelMemory();
        VerySimpleEntity entity = new VerySimpleEntity("name");
        Identifier identifier = identifierManager.getIdentifier();
        EntityProxy entityProxy = new EntityProxy(identifier, 
                                                  EntityManager.getInstance());

        VerySimpleEntity entity2 = new VerySimpleEntity("name2");
        Identifier identifier2 = identifierManager.getIdentifier();
        EntityProxy entityProxy2 = new EntityProxy(identifier2, 
                                                   EntityManager.getInstance());

        try {
            kernelmemory.loadIntoMemory(identifier, entity, entityProxy);
            kernelmemory.loadIntoMemory(identifier2, entity2, entityProxy2);
        } catch (Exception e) {
            System.err.println("Exception thrown:  " + e);
        }

        this.assertEquals(entity, kernelmemory.findEntity(identifier));
        this.assertEquals(entityProxy, kernelmemory.findProxy(identifier));
        this.assertEquals(identifier, kernelmemory.findIdentifier(entity));
    }

    public void testIsFull() throws DataManagerException {
        KernelMemory kernelmemory = new KernelMemory();
        VerySimpleEntity entity = new VerySimpleEntity("name");
        Identifier identifier = identifierManager.getIdentifier();
        EntityProxy entityProxy = new EntityProxy(identifier, 
                                                  EntityManager.getInstance());

        for (int i = 0; i < (kernelmemory.maxSize() + 1); i++) {
            try {
                kernelmemory.loadIntoMemory(identifier, entity, entityProxy);
                this.assertEquals(i + 1, kernelmemory.currentSize());
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        this.assertTrue(kernelmemory.isFull());

        try {
            kernelmemory.loadIntoMemory(identifier, entity, entityProxy);
            this.assertTrue(false);
        } catch (Exception e) {
            this.assertTrue(true);
        }
    }

    public void testFindOldestIdentifier() throws DataManagerException {
        KernelMemory kernelmemory = new KernelMemory();
        VerySimpleEntity entity = new VerySimpleEntity("name");
        Identifier identifier = identifierManager.getIdentifier();
        EntityProxy entityProxy = new EntityProxy(identifier, 
                                                  EntityManager.getInstance());

        try {
            kernelmemory.loadIntoMemory(identifier, entity, entityProxy);
        } catch (Exception e) {
            e.printStackTrace();
        }

        for (int i = 1; i < (kernelmemory.maxSize() + 1); i++) {
            VerySimpleEntity entity2 = new VerySimpleEntity("name" + i);
            Identifier identifier2 = identifierManager.getIdentifier();
            EntityProxy entityProxy2 = new EntityProxy(identifier2, 
                                                       EntityManager.getInstance());

            try {
                kernelmemory.loadIntoMemory(identifier2, entity2, entityProxy2);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        this.assertTrue(kernelmemory.isFull());
        this.assertEquals(identifier, kernelmemory.findOldestIdentifier());

        if (kernelmemory.isFull()) {
            Identifier firstIdentifier = kernelmemory.findOldestIdentifier();
            this.assertNotNull(firstIdentifier);

            VerySimpleEntity removedOldestEntity = (VerySimpleEntity) kernelmemory.removeFromMemory(
                                                           firstIdentifier);

            try {
                String name = removedOldestEntity.getName();
            } catch (Exception e) {
                e.printStackTrace();
            }

            this.assertEquals(removedOldestEntity, entity);
            this.assertNull(kernelmemory.findEntity(identifier));
        }
    }
}