// For licensing, see: http://helium.knownspace.org/license.html
// This has to go in kernel so we can create DataManagerWorkers.  Sigh.
package org.datamanager.kernel;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.constraint.AttributeNameContainsConstraint;
import org.datamanager.constraint.EntityConstraint;
import org.datamanager.constraint.OrEntityConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.DataManagerWorker;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.Simpleton;

import org.datamanager.passiveentityvalue.StringEntityValue;


public class OrEntityConstraintTester extends TestCase {
    Entity matchEntity;
    boolean matched;

    public OrEntityConstraintTester(String string) {
        super(string);
    }

    public static Test suite() {
        return new TestSuite(OrEntityConstraintTester.class);
    }

    public void setUp() {
        try {
            matchEntity = Entity.create("testMatch");

            Entity attribute1Entity = Entity.create("haiku");
            attribute1Entity.setValue(
                    new StringEntityValue(
                            "constraint unit test / match my attribute value / give boolean true"));
            matchEntity.attach(attribute1Entity);

            Entity attribute2Entity = Entity.create("free-verse");
            attribute2Entity.setValue(
                    new StringEntityValue(
                            "once, in simple pleasure, we late night rode"));
            matchEntity.attach(attribute2Entity);
        } catch (DataManagerException exception) {
            throw new RuntimeException(exception);
        }
    }

    public void setMatched(boolean matched) {
        this.matched = matched;
    }

    public boolean isMatched() {
        return matched;
    }

    boolean applyConstraint(final EntityConstraint constraint) {
        try {
            DataManagerWorker worker = new DataManagerWorker(new Simpleton() {
                public void process() {
                    try {
                        setMatched(constraint.accepts(matchEntity));
                    } catch (DataManagerException exception) {
                        fail(exception.toString());
                    }
                }
            });
            worker.generateEvents(true);
            worker.start();
            worker.join();
        } catch (java.lang.InterruptedException exception) {
            fail(exception.toString());
        }

        return matched;
    }

    /**
     * Tests that the constraint does not match Entities it should not.
     */
    public void testNoMatch() {
        setMatched(true);
        applyConstraint(
                new OrEntityConstraint(
                        new AttributeNameContainsConstraint("haiku", 
                                                            "baked chicken"), 
                        new AttributeNameContainsConstraint("free-verse", 
                                                            "carnal pleasure")));
        assertFalse(matched);
    }

    /**
     * Tests that the constraint matches when it's supposed to.
     * In this case on 1 || 0
     */
    public void testMatchTrueFalse() {
        setMatched(false);
        applyConstraint(
                new OrEntityConstraint(
                        new AttributeNameContainsConstraint("haiku", 
                                                            "unit test"), 
                        new AttributeNameContainsConstraint("free-verse", 
                                                            "carnal pleasure")));
    }

    /**
     * Tests that the constraint matches when it's supposed to.
     * In this case on 1 || 1
     */
    public void testMatchTrueTrue() {
        setMatched(false);
        applyConstraint(
                new OrEntityConstraint(
                        new AttributeNameContainsConstraint("haiku", 
                                                            "unit test"), 
                        new AttributeNameContainsConstraint("free-verse", 
                                                            "simple pleasure")));
        assertTrue(matched);
    }
}

/*
 * $Log: OrEntityConstraintTester.java,v $
 * Revision 1.4  2002/12/20 20:52:50  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.3  2002/11/03 17:53:56  mafarrel
 * Ran codebase-style...
 *
 * Revision 1.2  2002/10/30 08:29:10  cjdent
 *
 * Added a third case to catch when both subconstraints are true. May wish, to be
 * especially uptight, to add a fourth case to get 01. 00, 10 and 11 are currently
 * tested. What do other people think: Do we believe in Boolean?
 *
 * Revision 1.1  2002/10/30 08:17:32  cjdent
 *
 * Copies with modification of the AttributeNameContainsConstraintTester
 * for testing the AndEntityConstraint and OrEntityConstraint type of constraints.
 *
 */
