// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.kernel;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.constraint.*;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.*;

import org.datamanager.passiveentityvalue.*;


public class RecursiveOrEntityConstraintTester extends TestCase {
    private RecursiveOrEntityConstraint constraint;
    Entity testEntity;
    Entity firstAttribute;
    Entity secondAttribute;
    Entity thirdAttribute;
    Entity firstFirstAttribute;
    Entity secondFirstAttribute;
    Entity thirdFirstAttribute;
    Entity firstSecondAttribute;
    Entity secondSecondAttribute;
    Entity thirdSecondAttribute;
    Entity firstThirdAttribute;
    Entity secondThirdAttribute;
    Entity thirdThirdAttribute;

    public static Test suite() {
        return new TestSuite(RecursiveOrEntityConstraintTester.class);
    }

    protected void setUp() {
        try {
            testEntity = Entity.create("TestEntity");
            firstAttribute = Entity.create("FirstAttribute");
            secondAttribute = Entity.create("SecondAttribute");
            thirdAttribute = Entity.create("ThirdAttribute");

            firstFirstAttribute = Entity.create("FirstFirstAttribute");
            secondFirstAttribute = Entity.create("SecondFirstAttribute");
            thirdFirstAttribute = Entity.create("ThirdFirstAttribute");

            firstSecondAttribute = Entity.create("FirstSecondAttribute");
            secondSecondAttribute = Entity.create("SecondSecondAttribute");
            thirdSecondAttribute = Entity.create("ThirdSecondAttribute");

            firstThirdAttribute = Entity.create("FirstThirdAttribute");
            secondThirdAttribute = Entity.create("SecondThirdAttribute");
            thirdThirdAttribute = Entity.create("ThirdThirdAttribute");
            thirdThirdAttribute.setValue(new StringEntityValue("BigFun"));

            firstAttribute.attach(firstFirstAttribute);
            firstAttribute.attach(secondFirstAttribute);
            firstAttribute.attach(thirdFirstAttribute);

            secondAttribute.attach(firstSecondAttribute);
            secondAttribute.attach(secondSecondAttribute);
            secondAttribute.attach(thirdSecondAttribute);

            thirdAttribute.attach(firstThirdAttribute);
            thirdAttribute.attach(secondThirdAttribute);
            thirdAttribute.attach(thirdThirdAttribute);


            //  Setting up for mutual recursion
            firstAttribute.attach(secondAttribute);
            secondAttribute.attach(thirdAttribute);
            thirdAttribute.attach(firstAttribute);

            testEntity.attach(firstAttribute);
            testEntity.attach(secondAttribute);
            testEntity.attach(thirdAttribute);

            Pool.getDefaultPool().add(testEntity);
        } catch (DataManagerException e) {
            e.printStackTrace();
            System.err.println("Setup failed: " + e.getMessage());
        }
    }

    public void testMutualRecursion() throws DataManagerException, 
                                             InterruptedException {
        DataManagerWorker worker = new DataManagerWorker(new Simpleton() {
            public void process() {
                try {
                    Entity[] searchResults;
                    StringValueContainsConstraint stringValueContainsConstraint = 
                            new StringValueContainsConstraint("SmallFun");

                    RecursiveOrEntityConstraint recursiveOrEntityConstraint = 
                            new RecursiveOrEntityConstraint(
                                    stringValueContainsConstraint);
                    searchResults = Pool.getDefaultPool()
                                        .search(recursiveOrEntityConstraint);
                    assertTrue(searchResults.length == 0);

                    System.err.println(
                            "new value for thirdthird attribute is: " + thirdThirdAttribute.getValue());

                    stringValueContainsConstraint = new StringValueContainsConstraint(
                                                            "BigFun");
                    recursiveOrEntityConstraint = new RecursiveOrEntityConstraint(
                                                          stringValueContainsConstraint);

                    searchResults = Pool.getDefaultPool()
                                        .search(recursiveOrEntityConstraint);
                    System.err.println("searchResults size is: " + searchResults.length);
                    assertTrue(searchResults.length == 1);
                    assertEquals(searchResults[0], testEntity);
                } catch (DataManagerException e) {
                    e.printStackTrace();
                    fail(e.getMessage());
                }
            }
        });
        worker.generateEvents(true);
        worker.start();
        worker.join();
    }
}