// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.kernel;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.exception.DataManagerException;
import org.datamanager.exception.NoSuchEntityException;
import org.datamanager.exception.NoSuchIdentifierException;


/**
 * It should test the SuaveEntityManger 's all capability
 *
 * @author xi rao
 * @version $Revision: 1.9 $
 */
public class SuaveEntityManagerTester extends TestCase {
    public final static String ENTITY_NAME = "xirao";
    public final static String CLASS_PROPERTY = "org.datamanager.kernel.entity_manager.class";
    public final static String TEST_CLASS = "org.datamanager.kernel.SuaveEntityManager";
    String savedEntityManagerClassProperty;
    SuaveEntityManager suaveEntityManager;
    EntityProxy entityProxy;

    public SuaveEntityManagerTester(String string) {
        super(string);
    }

    protected void setUp() {
        savedEntityManagerClassProperty = System.getProperty(CLASS_PROPERTY);
        System.setProperty(CLASS_PROPERTY, TEST_CLASS);

        try {
            EntityManager.forgetInstance();
            suaveEntityManager = (SuaveEntityManager) SuaveEntityManager.getInstance();
            entityProxy = suaveEntityManager.createEntity(ENTITY_NAME);
        } catch (DataManagerException exception) {
            fail(exception.getMessage());
        }
    }

    public static Test suite() {
        return new TestSuite(SuaveEntityManagerTester.class);
    }

    protected void tearDown() {
        if (null == savedEntityManagerClassProperty) {
            // FIXME: This is ugly, because it requires "insider knowledge" of
            // EntityManager, but it seems to be the only way to fake resetting
            // of the property to null, since trying to actually set it to null
            // causes a NullPointerException to be thrown.
            System.setProperty(CLASS_PROPERTY, 
                               EntityManager.DEFAULT_IMPLEMENTATION_CLASS_NAME);
        } else {
            System.setProperty(CLASS_PROPERTY, savedEntityManagerClassProperty);
        }

        EntityManager.forgetInstance();
    }

    public void testGetInstance() {
        assertNotNull(suaveEntityManager);
    }

    public void testCreateEntity() throws DataManagerException {
        assertNotNull(entityProxy);
        assertEquals(ENTITY_NAME, entityProxy.getName());
    }

    public void testFindByIdentifier() throws DataManagerException {
        Identifier proxyIdentifier = suaveEntityManager.findIdentifier(
                                             entityProxy);
        Entity entity = suaveEntityManager.findEntity(proxyIdentifier);

        assertEquals(proxyIdentifier, suaveEntityManager.findIdentifier(entity));
    }

    public void testRetrieveFromStorage() throws DataManagerException {
        Identifier proxyIdentifier = suaveEntityManager.findIdentifier(
                                             entityProxy);

        for (int ii = 0; ii < KernelMemory.HASHTABLE_LENGTH; ii++) {
            suaveEntityManager.createEntity("test");
        }

        Entity entity = suaveEntityManager.findEntity(proxyIdentifier);
        Identifier identifier = suaveEntityManager.findIdentifier(entity);
        assertEquals(proxyIdentifier, identifier);
    }
}

/*
 *
 * $Log: SuaveEntityManagerTester.java,v $
 * Revision 1.9  2002/12/20 20:52:50  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.8  2002/12/05 11:55:09  alllee
 * Codebase-style.
 *
 * Revision 1.7  2002/12/03 05:13:35  mliggett
 * Added call to forgetInstance() so the test would actually be run against
 * SuaveEntityManager.
 *
 * Revision 1.6  2002/11/21 06:16:10  cjdent
 * full bore codebase style
 *
 * Revision 1.5  2002/11/21 02:58:26  mliggett
 * - EntityManager.getInstance() now loads the proper EntityManager class
 *   using reflection and the system property
 *   org.datamanager.entity_manager.class.  It defaults to
 *   VerySimpleEntityManager.
 *
 * - As a result of all the horrible things that could go wrong during
 *   reflection procedure, getInstance() now throws DataManagerException, and
 *   hence so do a few other methods now, too.
 *
 * - Added direct calls to removeEntityFromMemory() before every call to
 *   loadIntoMemory() to ensure that the hashtable never grows above the
 *   specified size.  This will be refactored in the next revision.
 *
 * - SuaveEntityManagerTester's test was exploded into four different tests.
 *   Also, it now sets and unsets the org.datamanager.entity_manager.class
 *   property before and after each test run, so that it knows it's testing
 *   the right class.
 *
 *
 */
