// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.kernel;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.constraint.AttributeNameContainsConstraint;
import org.datamanager.constraint.EntityConstraint;
import org.datamanager.constraint.ValueClassIsConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EntityValue;
import org.datamanager.kernel.Simpleton;

import org.datamanager.passiveentityvalue.StringEntityValue;

import org.datamanager.tools.JUnitTesterUtility;
import org.datamanager.tools.JUnitTesterUtility.KnownSpaceTest;


public class ValueClassIsConstraintTester extends TestCase {
    ValueClassIsConstraint constraintParent;
    ValueClassIsConstraint constraintChild;
    Entity entityParent;
    Entity entityChild;

    public ValueClassIsConstraintTester(String string) {
        super(string);
    }

    public static Test suite() {
        return new TestSuite(ValueClassIsConstraintTester.class);
    }

    public void setUp() {
        try {
            constraintParent = new ValueClassIsConstraint(
                                       EntityValueParent.class);

            constraintChild = new ValueClassIsConstraint(EntityValueChild.class);

            entityParent = Entity.create("Test Parent");
            entityParent.setValue(new EntityValueParent());

            entityChild = Entity.create("Test Child");
            entityChild.setValue(new EntityValueChild());
        } catch (DataManagerException exception) {
            throw new RuntimeException(exception);
        }
    }

    public void testParentAcceptsParent() throws DataManagerException {
        JUnitTesterUtility.runTest(new KnownSpaceTest() {
            public void test() throws Exception {
                assertTrue(constraintParent.accepts(entityParent));
            }
        });
    }

    public void testParentAcceptsChild() throws DataManagerException {
        JUnitTesterUtility.runTest(new KnownSpaceTest() {
            public void test() throws Exception {
                assertTrue(constraintParent.accepts(entityChild));
            }
        });
    }

    public void testChildAcceptsParent() throws DataManagerException {
        JUnitTesterUtility.runTest(new KnownSpaceTest() {
            public void test() throws Exception {
                assertFalse(constraintChild.accepts(entityParent));
            }
        });
    }

    public class EntityValueParent implements EntityValue {
    }

    public class EntityValueChild extends EntityValueParent {
    }
}