// For licensing, see: http://helium.knownspace.org/license.html
// This has to go in kernel so we can create DataManagerWorkers.  Sigh.
package org.datamanager.kernel;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.constraint.AttributeNameContainsConstraint;
import org.datamanager.constraint.EntityConstraint;
import org.datamanager.constraint.ValueEqualsConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.DataManagerWorker;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.Simpleton;

import org.datamanager.passiveentityvalue.StringEntityValue;

import org.datamanager.test.ConstraintApplier;


public class ValueEqualsConstraintTester extends TestCase {
    private static final String HAIKU = "constraint unit test / match my attribute value / give boolean true";
    Entity matchEntity;
    ConstraintApplier constraintApplier;

    public ValueEqualsConstraintTester(String string) {
        super(string);
    }

    public static Test suite() {
        return new TestSuite(ValueEqualsConstraintTester.class);
    }

    public void setUp() {
        try {
            matchEntity = Entity.create("haiku");

            matchEntity.setValue(new StringEntityValue(HAIKU));
        } catch (DataManagerException exception) {
            throw new RuntimeException(exception);
        }

        constraintApplier = new ConstraintApplier();
    }

    /**
     * Tests that the constraint does not match Entities it should not.
     */
    public void testNoMatch() throws InterruptedException {
        assertFalse(constraintApplier.applyConstraint(
                            new ValueEqualsConstraint(
                                    new StringEntityValue("flaccid ham")), 
                            matchEntity));
    }

    /**
     * Tests that the constraint matches when it's supposed to.
     */
    public void testMatch() throws InterruptedException {
        assertTrue(constraintApplier.applyConstraint(
                           new ValueEqualsConstraint(
                                   new StringEntityValue(HAIKU)), matchEntity));
    }
}

/*
 * $Log: ValueEqualsConstraintTester.java,v $
 * Revision 1.5  2002/12/20 20:52:50  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.4  2002/11/13 08:26:22  cjdent
 *
 * Codebase style.
 *
 * We need to decide if it is in or out. Most people don't seem to be
 * running codebase style before they commit.
 *
 * Revision 1.3  2002/11/07 05:39:18  mliggett
 * Tests rewritten to use ConstraintApplier, but we should probably use
 * JUnitTesterUtility instead (or atleast as a way to _implement_
 * ConstraintApplier).
 *
 * See these two messages:
 *
 *   http://www.burningchrome.com:81/archives/helium/200211/msg00427.html
 *   http://www.burningchrome.com:81/archives/helium/200211/msg00431.html
 *
 * Revision 1.2  2002/11/04 16:48:56  mafarrel
 * ran ant codebase-style...
 *
 * Revision 1.1  2002/11/04 03:27:22  mliggett
 * Fixed bug in StringEntityValue.equals(); also wrote unit tests to exercise the bugs.
 *
 */
