// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.passiveentityvalue;

import java.util.HashMap;
import java.util.Map;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.passiveentityvalue.WordFrequencyMapEntityValue;


public class WordFrequencyMapEntityValueTester extends TestCase {
    private static final String TEST_STRING_0 = "There are two occurrences of the sentence containing the sentence word 'occurrences' in this sentence.";
    private static final String TEST_STRING_1 = "Four score and seven years ago there once was a barfly in a french-fried maid outfit with obvious talent at lacking success.  Unfortunately, the world grew weary and the time went bleary and henceforth I was never ever more.  bleary argle bleary argle bleary argle bleary blopf.";
    private WordFrequencyMapEntityValue wfev0;
    private WordFrequencyMapEntityValue wfev1;

    public WordFrequencyMapEntityValueTester(String string) {
        super(string);
    }

    public static Test suite() {
        return new TestSuite(WordFrequencyMapEntityValueTester.class);
    }

    public void setUp() {
        wfev0 = new WordFrequencyMapEntityValue(TEST_STRING_0);
        wfev1 = new WordFrequencyMapEntityValue(TEST_STRING_1);
    }

    public void testEquals() {
        assertEquals(new WordFrequencyMapEntityValue(TEST_STRING_0), 
                     new WordFrequencyMapEntityValue(TEST_STRING_0));
    }

    public void testNotEquals() {
        assertFalse(new WordFrequencyMapEntityValue(TEST_STRING_0).equals(
                            new WordFrequencyMapEntityValue(TEST_STRING_1)));
    }

    public void testWordMapTotal() {
        assertTrue(15 == wfev0.getTotalNumberOfWords());
        assertTrue(48 == wfev1.getTotalNumberOfWords());
    }

    public void testWordMap() {
        Map wordFrequencyMap = wfev0.getWordFrequencyMap();
        assertEquals((Integer) wordFrequencyMap.get("two"), new Integer(1));
        assertEquals((Integer) wordFrequencyMap.get("occurrences"), 
                     new Integer(2));
        assertEquals((Integer) wordFrequencyMap.get("containing"), 
                     new Integer(1));
        assertEquals((Integer) wordFrequencyMap.get("sentence"), new Integer(3));

        wordFrequencyMap = wfev1.getWordFrequencyMap();
        assertEquals((Integer) wordFrequencyMap.get("score"), new Integer(1));
        assertEquals((Integer) wordFrequencyMap.get("barfly"), new Integer(1));
        assertEquals((Integer) wordFrequencyMap.get("french"), new Integer(1));
        assertEquals((Integer) wordFrequencyMap.get("bleary"), new Integer(5));
    }
}

/*
 * $Log: WordFrequencyMapEntityValueTester.java,v $
 * Revision 1.6  2002/12/20 20:52:52  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.5  2002/12/07 15:18:52  alllee
 * Changed unit tests for finding the total number of words in the
 * WordFrequencyMapEntityValue
 *
 * Revision 1.4  2002/12/06 20:03:58  alllee
 * Added tests for the magic WORD_TOTAL value that should contain the total
 * number of words in the word frequency Map.  ug.
 *
 * Revision 1.3  2002/12/05 12:15:00  alllee
 * Arggh.  Renaming woes once again.  I would blame this on stupidity more than
 * tiredness as I'm pretty alert right now.  No, really.
 *
 * Revision 1.2  2002/12/05 12:10:16  alllee
 * Renaming woes..
 *
 * Revision 1.1  2002/12/05 11:56:36  alllee
 * Unit test for WordFrequencyMapEntityValue.  This entity value is the
 * EntityValue of a new Word-Frequency attribute entity that gets
 * dangly-fondleabled onto all incoming Email Entity messages via
 * EmailRetrieverSimpleton.
 *
 */
