// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.simpleton;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;

import org.datamanager.passiveentityvalue.StringEntityValue;

import org.datamanager.simpleton.EmailMessageEntityHelper;


public class EmailMessageEntityHelperTester extends TestCase {
    public static String SUBJECT = "[helium] Re: CVS Update: helium/java/test/org/datamanager/tools";
    public static String FROM = "Chris Dent <cdent@burningchrome.com>";
    public static String TO = "<helium@burningchrome.com>";
    public static String DATE = "Sat, 16 Nov 2002 01:36:01 -0500 (EST)";
    public static String MESSAGE_ID = "<Pine.LNX.4.30.0211160135090.9956-100000@hot.burningchrome.com>";
    public static String IN_REPLY_TO = "<200211160633.gAG6X4r18513@tucotuco.cs.indiana.edu>";
    public static String BODY = "This reminds me: do we want to match on things like:\n\n   www.bigbooty.com/index.html\n\nin addition to the\n\n   http://www.bigbooty.com/index.html\n\nthat is already being matched?\n\nHow djb do we want to be?\n\n-- \nChris Dent  <cdent@burningchrome.com>  http://www.burningchrome.com/~cdent/\n\"If you assume that there is an instinct for freedom, that there are\nopportunities to change things, that hope is possible, then hope may be\njustified, and a better world may be built. That's your choice.\" N.Chomsky\n\n-- \nhelium archive & search: http://www.burningchrome.com:81/archives/helium/\nwiki: http://www.burningchrome.com:81/wikis/helium/\n\n";
    EmailMessageEntityHelper messageHelper;
    Entity message;
    EmailMessageEntityHelper emptyMessageHelper;

    public EmailMessageEntityHelperTester(String string) {
        super(string);
    }

    public static Test suite() {
        return new TestSuite(EmailMessageEntityHelperTester.class);
    }

    public void attachStringAttribute(String name, String value)
                               throws DataManagerException {
        Entity attributeEntity = Entity.create(name);
        attributeEntity.setValue(new StringEntityValue(value));
        message.attach(attributeEntity);
    }

    public void setUp() {
        try {
            message = Entity.create(
                              "<Pine.LNX.4.30.0211120220070.24961-100000@hot.burningchrome.com>");

            attachStringAttribute("content-source", "email");
            attachStringAttribute("Return-Path", 
                                  "<helium-request@burningchrome.com>");
            attachStringAttribute("Delivered-To", "mml@lazlo.bloomington.in.us");
            attachStringAttribute("Received", 
                                  "(qmail 26686 invoked from network); 16 Nov 2002 06:36:07 -0000");
            attachStringAttribute("Received", 
                                  "from dolly1.pobox.com (207.106.49.22) by lazlo.mml.bloomington.in.us with SMTP; 16 Nov 2002 06:36:07 -0000");
            attachStringAttribute("Received", 
                                  "from dolly1.pobox.com (localhost.localdomain [127.0.0.1]) by dolly1.pobox.com (Postfix) with ESMTP id 92B262BEF5; Sat, 16 Nov 2002 01:36:06 -0500 (EST)");
            attachStringAttribute("Delivered-To", "mml@pobox.com");
            attachStringAttribute("Received", 
                                  "from hot.burningchrome.com (cust-216-9-146-10.bton.kiva.net [216.9.146.10]) by dolly1.pobox.com (Postfix) with ESMTP id 1ED542BFA0 for <mml@pobox.com>; Sat, 16 Nov 2002 01:36:06 -0500 (EST)");
            attachStringAttribute("Received", 
                                  "(from slist@localhost) by hot.burningchrome.com (8.11.2/8.11.2) id gAG6a2K13319; Sat, 16 Nov 2002 01:36:02 -0500");
            attachStringAttribute("Resent-Date", 
                                  "Sat, 16 Nov 2002 01:36:01 -0500");
            attachStringAttribute("X-Authentication-Warning", 
                                  "hot.burningchrome.com: slist set sender to helium-request@burningchrome.com using -f");
            attachStringAttribute("Date", DATE);
            attachStringAttribute("From", FROM);
            attachStringAttribute("To", TO);
            attachStringAttribute("In-Reply-To", IN_REPLY_TO);
            attachStringAttribute("Message-ID", MESSAGE_ID);
            attachStringAttribute("MIME-Version", "1.0");
            attachStringAttribute("Content-Type", 
                                  "TEXT/PLAIN; charset=US-ASCII");
            attachStringAttribute("Resent-Message-ID", 
                                  "<r1Oiz.A.4PD.Rde19@hot.burningchrome.com>");
            attachStringAttribute("Resent-From", "helium@burningchrome.com");
            attachStringAttribute("X-Mailing-List", 
                                  "<helium@burningchrome.com> archive/latest/1891");
            attachStringAttribute("X-Loop", "helium@burningchrome.com");
            attachStringAttribute("Reply-To", "helium@burningchrome.com");
            attachStringAttribute("Precedence", "list");
            attachStringAttribute("Resent-Sender", 
                                  "helium-request@burningchrome.com");
            attachStringAttribute("Subject", SUBJECT);
            attachStringAttribute("part0", BODY);
            messageHelper = new EmailMessageEntityHelper(message);
            emptyMessageHelper = new EmailMessageEntityHelper();
        } catch (DataManagerException exception) {
            throw new RuntimeException(exception);
        }
    }

    public void testGetMessage() throws DataManagerException {
        assertSame(message, messageHelper.getMessage());
    }

    public void testGetSubject() throws DataManagerException {
        assertEquals(SUBJECT, messageHelper.getSubject());
    }

    public void testGetFrom() throws DataManagerException {
        assertEquals(FROM, messageHelper.getFromAddress());
    }

    public void testGetTo() throws DataManagerException {
        assertEquals(TO, messageHelper.getToAddresses());
    }

    public void testGetCc() throws DataManagerException {
        assertEquals("", messageHelper.getCcAddresses());
    }

    public void testGetDate() throws DataManagerException {
        assertEquals(DATE, messageHelper.getDateString());
    }

    public void testGetInReplyTo() throws DataManagerException {
        assertEquals(IN_REPLY_TO, messageHelper.getInReplyTo());
    }

    public void testGetMessageId() throws DataManagerException {
        assertEquals(MESSAGE_ID, messageHelper.getMessageId());
    }

    public void testGetContentType() throws DataManagerException {
        assertEquals("text/plain", messageHelper.getContentType());
    }

    public void testGetBody() throws DataManagerException {
        assertEquals(BODY, messageHelper.getBody());
    }

    public void testGetEmptySubject() throws DataManagerException {
        assertEquals("", emptyMessageHelper.getSubject());
    }

    public void testSetGetSubject() throws DataManagerException {
        emptyMessageHelper.setSubject(SUBJECT);
        assertEquals(SUBJECT, emptyMessageHelper.getSubject());
    }

    public void testGetEmptyFrom() throws DataManagerException {
        assertEquals("", emptyMessageHelper.getFromAddress());
    }

    public void testSetGetFrom() throws DataManagerException {
        emptyMessageHelper.setFromAddress(FROM);
        assertEquals(FROM, emptyMessageHelper.getFromAddress());
    }

    public void testGetEmptyTo() throws DataManagerException {
        assertEquals("", emptyMessageHelper.getToAddresses());
    }

    public void testSetGetTo() throws DataManagerException {
        emptyMessageHelper.setToAddresses(TO);
        assertEquals(TO, emptyMessageHelper.getToAddresses());
    }

    public void testGetEmptyCc() throws DataManagerException {
        assertEquals("", emptyMessageHelper.getCcAddresses());
    }

    public void testSetGetCc() throws DataManagerException {
        String address = "mail@box.com";

        emptyMessageHelper.setCcAddresses(address);
        assertEquals(address, emptyMessageHelper.getCcAddresses());
    }

    public void testGetEmptyDate() throws DataManagerException {
        assertEquals("", emptyMessageHelper.getDateString());
    }

    public void testSetGetDate() throws DataManagerException {
        emptyMessageHelper.setDateString(DATE);
        assertEquals(DATE, emptyMessageHelper.getDateString());
    }

    public void testGetEmptyMessageId() throws DataManagerException {
        assertEquals("", emptyMessageHelper.getMessageId());
    }

    public void testSetGetMessageId() throws DataManagerException {
        emptyMessageHelper.setMessageId(MESSAGE_ID);
        assertEquals(MESSAGE_ID, emptyMessageHelper.getMessageId());
    }

    public void testGetEmptyInReplyTo() throws DataManagerException {
        assertEquals("", emptyMessageHelper.getInReplyTo());
    }

    public void testSetGetInReplyTo() throws DataManagerException {
        emptyMessageHelper.setInReplyTo(MESSAGE_ID);
        assertEquals(MESSAGE_ID, emptyMessageHelper.getInReplyTo());
    }
}