// For licensing, see: http://helium.knownspace.org/license.html
package org.datamanager.tools;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.tools.Toolbox;


/** Tests the utility functions within the Toolbox class. */
public class ToolboxTester extends TestCase {
    public ToolboxTester(String name) {
        super(name);
    }

    public static Test suite() {
        return new TestSuite(ToolboxTester.class);
    }

    public void setUp() {
    }

    public void tearDown() {
    }

    public void testTextToPreHtml() {
        final String text0 = "Hey: http://www.indiana.edu is down again.  What should do?  Perhaps we should go to http://www.fark.com instead and blindly\n waste hours of our lives reading about people that are doing pointless things.  Or, https://www.hotvegetableaction.goat.box.com might be up and we should go there instead.  That's right.  http://www.indiana.edu. https://www.indiana.edu.";
        final String text0Answer = "<html><pre>Hey: <a href='http://www.indiana.edu'>http://www.indiana.edu</a> is down again.  What should do?  Perhaps we should go to <a href='http://www.fark.com'>http://www.fark.com</a> instead and blindly\n waste hours of our lives reading about people that are doing pointless things.  Or, <a href='https://www.hotvegetableaction.goat.box.com'>https://www.hotvegetableaction.goat.box.com</a> might be up and we should go there instead.  That's right.  <a href='http://www.indiana.edu'>http://www.indiana.edu</a>. <a href='https://www.indiana.edu'>https://www.indiana.edu</a>.</pre></html>";
        final String text0PreHtml = Toolbox.textToPreHtml(text0);
        assertEquals(text0Answer, text0PreHtml);
    }

    public void testSearchAndReplace() {
        final String text0 = "This string <pre>has</pre> \npre stuff.";
        final String text0Answer = "This string &lt;pre>has&lt;/pre> \npre stuff.";

        assertEquals(text0Answer, Toolbox.searchAndReplace(text0, "<", "&lt;"));
    }
} // ToolboxTester
/*
 * $Log: ToolboxTester.java,v $
 * Revision 1.4  2002/12/20 20:52:56  mliggett
 * Adding/modifying license tag on all source files.
 *
 * Revision 1.3  2002/11/23 07:07:31  cjdent
 *
 * Toolbox changed to adjust textToPreHTML to use a
 * searchAndReplace() method to find < and > in
 * body content and change it to &lt; and &gt; before
 * it is displayed in EmailDisplaySimpleton.
 *
 * Added a test to ToolboxTester to test searchAndReplace()
 * (I made it public because it probably useful).
 *
 * Revision 1.2  2002/11/16 18:45:19  mliggett
 * Added methods to request the components that are handling To: From:, etc.
 * display to the EmailMessageComponent interface.
 *
 * Using those, extracted the metadata search code from
 * BasicEmailMessageComponent back into EmailDisplaySimpleton, so that
 * BasicEmailMessageComponent is more generic.
 *
 * Revision 1.1  2002/11/16 06:33:04  alllee
 * Initial revision of Toolbox utility class test suite.  Only tests
 * textToPreHtml() currently.  More thorough testing of textToPreHtml is
 * imminent.
 *
 */
